"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *
import enum


class QBluetoothSocket(QtCore.QIODevice):
    """
    https://doc.qt.io/qt-6/qbluetoothsocket.html

    **Detailed Description**

    QBluetoothSocket supports two socket types, **L2CAP**  and **RFCOMM** .

    **L2CAP**  is a low level datagram-oriented Bluetooth socket. Android does
    not support **L2CAP**  for socket connections.

    **RFCOMM**  is a reliable, stream-oriented socket. RFCOMM sockets emulate an
    RS-232 serial port.

    To create a connection to a Bluetooth service, create a socket of the
    appropriate type and call **connectToService** () passing the Bluetooth
    address and port number. QBluetoothSocket will emit the **connected** ()
    signal when the connection is established.

    If the **Protocol**  is not supported on a platform, calling
    **connectToService** () will emit a **UnsupportedProtocolError**  error.

    **Note:** QBluetoothSocket does not support synchronous read and write
    operations. Functions such as **waitForReadyRead** () and
    **waitForBytesWritten** () are not implemented. I/O operations should be
    performed using **readyRead** (), **read** () and **write** ().

    On iOS, this class cannot be used because the platform does not expose an
    API which may permit access to QBluetoothSocket related features.
    """

    class SocketError(enum.Enum):
        NoSocketError: QBluetoothSocket = ...
        UnknownSocketError: QBluetoothSocket = ...
        RemoteHostClosedError: QBluetoothSocket = ...
        HostNotFoundError: QBluetoothSocket = ...
        ServiceNotFoundError: QBluetoothSocket = ...
        NetworkError: QBluetoothSocket = ...
        UnsupportedProtocolError: QBluetoothSocket = ...
        OperationError: QBluetoothSocket = ...

    class SocketState(enum.Enum):
        UnconnectedState: QBluetoothSocket = ...
        ServiceLookupState: QBluetoothSocket = ...
        ConnectingState: QBluetoothSocket = ...
        ConnectedState: QBluetoothSocket = ...
        BoundState: QBluetoothSocket = ...
        ClosingState: QBluetoothSocket = ...
        ListeningState: QBluetoothSocket = ...

    @typing.overload
    def __init__(
        self,
        socketType: QBluetoothServiceInfo.Protocol,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#QBluetoothSocket

        **QBluetoothSocket::QBluetoothSocket(QBluetoothServiceInfo::Protocol
        socketType , QObject * parent = nullptr)**

        Constructs a Bluetooth socket of **socketType** type, with **parent**.
        """
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#QBluetoothSocket-1

        **QBluetoothSocket::QBluetoothSocket(QObject * parent = nullptr)**

        Constructs a Bluetooth socket with **parent**.
        """
        ...

    def preferredSecurityFlags(self) -> QBluetooth.Security:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#preferredSecurityFlags

        **[since 5.6] QBluetooth::SecurityFlags
        QBluetoothSocket::preferredSecurityFlags() const**

        Returns the security parameters used for the initial connection attempt.

        The security parameters may be renegotiated between the two parties
        during or after the connection has been established. If such a change
        happens it is not reflected in the value of this flag.

        On macOS, this flag is always set to **QBluetooth::Security::Secure** .

        This function was introduced in Qt 5.6.

        **See also** **setPreferredSecurityFlags** ().
        """
        ...

    def setPreferredSecurityFlags(self, flags: QBluetooth.Security) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#setPreferredSecurityFlags

        **[since 5.6] void
        QBluetoothSocket::setPreferredSecurityFlags(QBluetooth::SecurityFlags
        flags )**

        Sets the preferred security parameter for the connection attempt to
        **flags**. This value is incorporated when calling **connectToService**
        (). Therefore it is required to reconnect to change this parameter for
        an existing connection.

        On Bluez this property is set to **QBluetooth::Security::Authorization**
        by default.

        On macOS, this value is ignored as the platform does not permit access
        to the security parameter of the socket. By default the platform prefers
        secure/encrypted connections though and therefore this function always
        returns **QBluetooth::Security::Secure** .

        Android only supports two levels of security (secure and non-secure). If
        this flag is set to **QBluetooth::Security::NoSecurity**  the socket
        object will not employ any authentication or encryption. Any other
        security flag combination will trigger a secure Bluetooth connection.
        This flag is set to **QBluetooth::Security::Secure**  by default.

        **Note:** A secure connection requires a pairing between the two
        devices. On some platforms, the pairing is automatically initiated
        during the establishment of the connection. Other platforms require the
        application to manually trigger the pairing before attempting to
        connect.

        This function was introduced in Qt 5.6.

        **See also** **preferredSecurityFlags** ().
        """
        ...

    def doDeviceDiscovery(
        self,
        service: QBluetoothServiceInfo,
        openMode: QtCore.QIODeviceBase.OpenModeFlag,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#doDeviceDiscovery

        **[protected] void QBluetoothSocket::doDeviceDiscovery(const
        QBluetoothServiceInfo & service , QIODeviceBase::OpenMode openMode )**

        Start device discovery for **service** and open the socket with
        **openMode**. If the socket is created with a service uuid device
        address, use service discovery to find the port number to connect to.
        """
        ...

    def setSocketError(self, error: "QBluetoothSocket.SocketError") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#setSocketError

        **[protected] void
        QBluetoothSocket::setSocketError(QBluetoothSocket::SocketError error_
        )**

        Sets the type of error that last occurred to **error_**.
        """
        ...

    def setSocketState(self, state: "QBluetoothSocket.SocketState") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#setSocketState

        **[protected] void
        QBluetoothSocket::setSocketState(QBluetoothSocket::SocketState state )**

        Sets the socket state to **state**.
        """
        ...

    def writeData(self, data: bytes) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#writeData

        **[override virtual protected] qint64 QBluetoothSocket::writeData(const
        char * data , qint64 maxSize )**

        Reimplements: **QIODevice::writeData** (const char *data, qint64
        maxSize).
        """
        ...

    def readData(self, maxlen: int) -> bytes:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#readData

        **[override virtual protected] qint64 QBluetoothSocket::readData(char *
        data , qint64 maxSize )**

        Reimplements: **QIODevice::readData** (char *data, qint64 maxSize).
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#errorString

        **QString QBluetoothSocket::errorString() const**

        Returns a user displayable text string for the error.
        """
        ...

    def error(self) -> "QBluetoothSocket.SocketError":
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#error

        **QBluetoothSocket::SocketError QBluetoothSocket::error() const**

        Returns the last error.
        """
        ...

    def state(self) -> "QBluetoothSocket.SocketState":
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#state

        **QBluetoothSocket::SocketState QBluetoothSocket::state() const**

        Returns the current state of the socket.
        """
        ...

    def socketType(self) -> QBluetoothServiceInfo.Protocol:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#socketType

        **QBluetoothServiceInfo::Protocol QBluetoothSocket::socketType() const**

        Returns the socket type. The socket automatically adjusts to the
        protocol offered by the remote service.

        Android only support **RFCOMM**  based sockets.
        """
        ...

    def socketDescriptor(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#socketDescriptor

        **int QBluetoothSocket::socketDescriptor() const**

        Returns the platform-specific socket descriptor, if available. This
        function returns -1 if the descriptor is not available or an error has
        occurred.

        **See also** **setSocketDescriptor** ().
        """
        ...

    def setSocketDescriptor(
        self,
        socketDescriptor: int,
        socketType: QBluetoothServiceInfo.Protocol,
        state: "QBluetoothSocket.SocketState" = ...,
        mode: QtCore.QIODeviceBase.OpenModeFlag = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#setSocketDescriptor

        **bool QBluetoothSocket::setSocketDescriptor(int socketDescriptor ,
        QBluetoothServiceInfo::Protocol socketType ,
        QBluetoothSocket::SocketState socketState = SocketState::ConnectedState,
        QIODeviceBase::OpenMode openMode = ReadWrite)**

        Set the socket to use **socketDescriptor** with a type of **socketType**
        , which is in state, **socketState** , and mode, **openMode**.

        Returns true on success

        **See also** **socketDescriptor** ().
        """
        ...

    def peerPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#peerPort

        **quint16 QBluetoothSocket::peerPort() const**

        Return the port number of the peer socket if available, otherwise
        returns 0. On Android, this feature is not supported.
        """
        ...

    def peerAddress(self) -> QBluetoothAddress:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#peerAddress

        **QBluetoothAddress QBluetoothSocket::peerAddress() const**

        Returns the address of the peer device.
        """
        ...

    def peerName(self) -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#peerName

        **QString QBluetoothSocket::peerName() const**

        Returns the name of the peer device.
        """
        ...

    def localPort(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#localPort

        **quint16 QBluetoothSocket::localPort() const**

        Returns the port number of the local socket if available, otherwise
        returns 0. Although some platforms may differ the socket must generally
        be connected to guarantee the return of a valid port number.

        On Android and macOS, this feature is not supported and returns 0.
        """
        ...

    def localAddress(self) -> QBluetoothAddress:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#localAddress

        **QBluetoothAddress QBluetoothSocket::localAddress() const**

        Returns the address of the local device.

        Although some platforms may differ the socket must generally be
        connected to guarantee the return of a valid address. In particular,
        this is true when dealing with platforms that support multiple local
        Bluetooth adapters.
        """
        ...

    def localName(self) -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#localName

        **QString QBluetoothSocket::localName() const**

        Returns the name of the local device.

        Although some platforms may differ the socket must generally be
        connected to guarantee the return of a valid name. In particular, this
        is true when dealing with platforms that support multiple local
        Bluetooth adapters.
        """
        ...

    def disconnectFromService(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#disconnectFromService

        **void QBluetoothSocket::disconnectFromService()**

        Attempts to close the socket. If there is pending data waiting to be
        written **QBluetoothSocket**  will enter **ClosingState**  and wait
        until all data has been written. Eventually, it will enter
        **UnconnectedState**  and emit the **disconnected** () signal.

        **See also** **connectToService** ().
        """
        ...

    @typing.overload
    def connectToService(
        self,
        address: QBluetoothAddress,
        uuid: "QBluetoothUuid.ServiceClassUuid",
        mode: QtCore.QIODeviceBase.OpenModeFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#connectToService

        **void QBluetoothSocket::connectToService(const QBluetoothServiceInfo &
        service , QIODeviceBase::OpenMode openMode = ReadWrite)**

        Attempts to connect to the service described by **service**.

        The socket is opened in the given **openMode**. The **socketType** () is
        ignored if **service** specifies a differing
        **QBluetoothServiceInfo::socketProtocol** ().

        The socket first enters **ConnectingState**  and attempts to connect to
        the device providing **service**. If a connection is established,
        **QBluetoothSocket**  enters **ConnectedState**  and emits **connected**
        ().

        At any point, the socket can emit **error** () to signal that an error
        occurred.

        Note that most platforms require a pairing prior to connecting to the
        remote device. Otherwise the connection process may fail.

        On Android, only RFCOMM connections are possible. This function ignores
        any socket protocol indicator and assumes RFCOMM.

        **See also** **state** () and **disconnectFromService** ().
        """
        ...

    @typing.overload
    def connectToService(
        self,
        address: QBluetoothAddress,
        port: int,
        mode: QtCore.QIODeviceBase.OpenModeFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#connectToService-1

        **void QBluetoothSocket::connectToService(const QBluetoothAddress &
        address , const QBluetoothUuid & uuid , QIODeviceBase::OpenMode openMode
        = ReadWrite)**

        Attempts to make a connection to the service identified by **uuid** on
        the device with address **address**.

        The socket is opened in the given **openMode**.

        For BlueZ, the socket first enters the **ServiceLookupState**  and
        queries the connection parameters for **uuid**. If the service
        parameters are successfully retrieved the socket enters
        **ConnectingState** , and attempts to connect to **address**. If a
        connection is established, **QBluetoothSocket**  enters
        **ConnectedState**  and emits **connected** ().

        On Android, the service connection can directly be established using the
        UUID of the remote service. Therefore the platform does not require the
        **ServiceLookupState**  and **socketType** () is always set to
        **QBluetoothServiceInfo::RfcommProtocol** .

        At any point, the socket can emit **error** () to signal that an error
        occurred.

        Note that most platforms require a pairing prior to connecting to the
        remote device. Otherwise the connection process may fail.

        **See also** **state** () and **disconnectFromService** ().
        """
        ...

    @typing.overload
    def connectToService(
        self,
        address: QBluetoothAddress,
        uuid: "QBluetoothUuid",
        mode: QtCore.QIODeviceBase.OpenModeFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#connectToService-2

        **void QBluetoothSocket::connectToService(const QBluetoothAddress &
        address , quint16 port , QIODeviceBase::OpenMode openMode = ReadWrite)**

        Attempts to make a connection with **address** on the given **port**.

        The socket is opened in the given **openMode**.

        The socket first enters **ConnectingState** , and attempts to connect to
        **address**. If a connection is established, **QBluetoothSocket**
        enters **ConnectedState**  and emits **connected** ().

        At any point, the socket can emit **error** () to signal that an error
        occurred.

        On Android and BlueZ (version 5.46 or above), a connection to a service
        can not be established using a port. Calling this function will emit a
        **ServiceNotFoundError** .

        Note that most platforms require a pairing prior to connecting to the
        remote device. Otherwise the connection process may fail.

        **See also** **state** () and **disconnectFromService** ().
        """
        ...

    @typing.overload
    def connectToService(
        self,
        service: QBluetoothServiceInfo,
        mode: QtCore.QIODeviceBase.OpenModeFlag = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#connectToService

        **void QBluetoothSocket::connectToService(const QBluetoothServiceInfo &
        service , QIODeviceBase::OpenMode openMode = ReadWrite)**

        Attempts to connect to the service described by **service**.

        The socket is opened in the given **openMode**. The **socketType** () is
        ignored if **service** specifies a differing
        **QBluetoothServiceInfo::socketProtocol** ().

        The socket first enters **ConnectingState**  and attempts to connect to
        the device providing **service**. If a connection is established,
        **QBluetoothSocket**  enters **ConnectedState**  and emits **connected**
        ().

        At any point, the socket can emit **error** () to signal that an error
        occurred.

        Note that most platforms require a pairing prior to connecting to the
        remote device. Otherwise the connection process may fail.

        On Android, only RFCOMM connections are possible. This function ignores
        any socket protocol indicator and assumes RFCOMM.

        **See also** **state** () and **disconnectFromService** ().
        """
        ...

    def canReadLine(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#canReadLine

        **[override virtual] bool QBluetoothSocket::canReadLine() const**

        Reimplements: **QIODevice::canReadLine() const** .

        Returns true if you can read at least one line from the device
        """
        ...

    def bytesToWrite(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#bytesToWrite

        **[override virtual] qint64 QBluetoothSocket::bytesToWrite() const**

        Reimplements: **QIODevice::bytesToWrite() const** .

        Returns the number of bytes that are waiting to be written. The bytes
        are written when control goes back to the event loop.
        """
        ...

    def bytesAvailable(self) -> int:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#bytesAvailable

        **[override virtual] qint64 QBluetoothSocket::bytesAvailable() const**

        Reimplements: **QIODevice::bytesAvailable() const** .

        Returns the number of incoming bytes that are waiting to be read.

        **See also** **bytesToWrite** () and **read** ().
        """
        ...

    def isSequential(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#isSequential

        **[override virtual] bool QBluetoothSocket::isSequential() const**

        Reimplements: **QIODevice::isSequential() const** .
        """
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#close

        **[override virtual] void QBluetoothSocket::close()**

        Reimplements: **QIODevice::close** ().

        Disconnects the socket's connection with the device.

        **Note:** On Android, closing the socket requires asynchronous
        interaction with Android threads. Therefore the associated
        **disconnected** () and **stateChanged** () signals are delayed until
        the threads have finished the closure.
        """
        ...

    def abort(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#abort

        **void QBluetoothSocket::abort()**

        Aborts the current connection and resets the socket. Unlike
        **disconnectFromService** (), this function immediately closes the
        socket, discarding any pending data in the write buffer.

        **Note:** On Android, aborting the socket requires asynchronous
        interaction with Android threads. Therefore the associated
        **disconnected** () and **stateChanged** () signals are delayed until
        the threads have finished the closure.

        **See also** **disconnectFromService** () and **close** ().
        """
        ...

    @property
    def connected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#connected

        **[signal] void QBluetoothSocket::connected()**

        This signal is emitted when a connection is established.

        **See also** **QBluetoothSocket::SocketState::ConnectedState**  and
        **stateChanged** ().
        """
        ...

    @property
    def disconnected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#disconnected

        **[signal] void QBluetoothSocket::disconnected()**

        This signal is emitted when the socket is disconnected.

        **See also** **QBluetoothSocket::SocketState::UnconnectedState**  and
        **stateChanged** ().
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#errorOccurred

        **[signal, since 6.2] void
        QBluetoothSocket::errorOccurred(QBluetoothSocket::SocketError error )**

        This signal is emitted when an **error** occurs.

        This function was introduced in Qt 6.2.

        **See also** **error** ().
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothsocket.html#stateChanged

        **[signal] void
        QBluetoothSocket::stateChanged(QBluetoothSocket::SocketState state )**

        This signal is emitted when the socket state changes to **state**.

        **See also** **connected** (), **disconnected** (), **state** (), and
        **QBluetoothSocket::SocketState** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QAuthenticator(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qauthenticator.html

    **Detailed Description**

    The QAuthenticator class is usually used in the **authenticationRequired**
    () and **proxyAuthenticationRequired** () signals of
    **QNetworkAccessManager**  and **QAbstractSocket** . The class provides a
    way to pass back the required authentication information to the socket when
    accessing services that require authentication.

    QAuthenticator supports the following authentication methods:

    * Basic
      * NTLM version 2
      * Digest-MD5
      * SPNEGO/Negotiate

    **Options**

    In addition to the username and password required for authentication, a
    QAuthenticator object can also contain additional options. The **options**
    () function can be used to query incoming options sent by the server; the
    **setOption** () function can be used to set outgoing options, to be
    processed by the authenticator calculation. The options accepted and
    provided depend on the authentication type (see method()).

    The following tables list known incoming options as well as accepted
    outgoing options. The list of incoming options is not exhaustive, since
    servers may include additional information at any time. The list of outgoing
    options is exhaustive, however, and no unknown options will be treated or
    sent back to the server.

    **Basic**

    OptionDirectionTypeDescription
    `realm`Incoming**QString** Contains the
    realm of the authentication, the same as **realm** ()

    The Basic authentication mechanism supports no outgoing options.

    **NTLM version 2**

    The NTLM authentication mechanism currently supports no incoming or outgoing
    options. On Windows, if no **user** has been set, domain\\user credentials
    will be searched for on the local system to enable Single-Sign-On
    functionality.

    **Digest-MD5**

    OptionDirectionTypeDescription
    `realm`Incoming**QString** Contains the
    realm of the authentication, the same as **realm** ()

    The Digest-MD5 authentication mechanism supports no outgoing options.

    **SPNEGO/Negotiate**

    This authentication mechanism currently supports no incoming or outgoing
    options.

    **See also** **QSslSocket** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qauthenticator.html#QAuthenticator

        **QAuthenticator::QAuthenticator()**

        Constructs an empty authentication object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QAuthenticator") -> None:
        """
        https://doc.qt.io/qt-6/qauthenticator.html#QAuthenticator-1

        **QAuthenticator::QAuthenticator(const QAuthenticator & other )**

        Constructs a copy of **other**.
        """
        ...

    def setOption(self, opt: str, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qauthenticator.html#setOption

        **void QAuthenticator::setOption(const QString & opt , const QVariant &
        value )**

        Sets the outgoing option **opt** to value **value**. See the **Options
        section**  for more information on outgoing options.

        **See also** **options** (), **option** (), and **QAuthenticator
        options** .
        """
        ...

    def options(self) -> typing.Dict[str, typing.Any]:
        """
        https://doc.qt.io/qt-6/qauthenticator.html#options

        **QVariantHash QAuthenticator::options() const**

        Returns all incoming options set in this **QAuthenticator**  object by
        parsing the server reply. See the **Options section**  for more
        information on incoming options.

        **See also** **option** () and **QAuthenticator options** .
        """
        ...

    def option(self, opt: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qauthenticator.html#option

        **QVariant QAuthenticator::option(const QString & opt ) const**

        Returns the value related to option **opt** if it was set by the server.
        See the **Options section**  for more information on incoming options.
        If option **opt** isn't found, an invalid **QVariant**  will be
        returned.

        **See also** **setOption** (), **options** (), and **QAuthenticator
        options** .
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qauthenticator.html#isNull

        **bool QAuthenticator::isNull() const**

        Returns `true` if the object has not been initialized. Returns `false`
        if non-const member functions have been called, or the content was
        constructed or copied from another initialized **QAuthenticator**
        object.
        """
        ...

    def realm(self) -> str:
        """
        https://doc.qt.io/qt-6/qauthenticator.html#realm

        **QString QAuthenticator::realm() const**

        Returns the realm requiring authentication.
        """
        ...

    def setPassword(self, password: str) -> None:
        """
        https://doc.qt.io/qt-6/qauthenticator.html#setPassword

        **void QAuthenticator::setPassword(const QString & password )**

        Sets the **password** used for authentication.

        **See also** **password** () and
        **QNetworkAccessManager::authenticationRequired** ().
        """
        ...

    def password(self) -> str:
        """
        https://doc.qt.io/qt-6/qauthenticator.html#password

        **QString QAuthenticator::password() const**

        Returns the password used for authentication.

        **See also** **setPassword** ().
        """
        ...

    def setUser(self, user: str) -> None:
        """
        https://doc.qt.io/qt-6/qauthenticator.html#setUser

        **void QAuthenticator::setUser(const QString & user )**

        Sets the **user** used for authentication.

        **See also** **user** () and
        **QNetworkAccessManager::authenticationRequired** ().
        """
        ...

    def user(self) -> str:
        """
        https://doc.qt.io/qt-6/qauthenticator.html#user

        **QString QAuthenticator::user() const**

        Returns the user used for authentication.

        **See also** **setUser** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QImageIOHandler(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qimageiohandler.html

    **Detailed Description**

    Qt uses QImageIOHandler for reading and writing images through
    **QImageReader**  and **QImageWriter** . You can also derive from this class
    to write your own image format handler using Qt's plugin mechanism.

    Call **setDevice** () to assign a device to the handler, and **setFormat**
    () to assign a format to it. One QImageIOHandler may support more than one
    image format. **canRead** () returns `true` if an image can be read from the
    device, and **read** () and **write** () return true if reading or writing
    an image was completed successfully.

    QImageIOHandler also has support for animations formats, through the
    functions **loopCount** (), **imageCount** (), **nextImageDelay** () and
    **currentImageNumber** ().

    In order to determine what options an image handler supports, Qt will call
    **supportsOption** () and **setOption** (). Make sure to reimplement these
    functions if you can provide support for any of the options in the
    **ImageOption**  enum.

    To write your own image handler, you must at least reimplement **canRead**
    () and **read** (). Then create a **QImageIOPlugin**  that can create the
    handler. Finally, install your plugin, and **QImageReader**  and
    **QImageWriter**  will then automatically load the plugin, and start using
    it.

    **See also** **QImageIOPlugin** , **QImageReader** , and **QImageWriter** .
    """

    class Transformation(enum.Flag):
        TransformationNone: QImageIOHandler = ...
        TransformationMirror: QImageIOHandler = ...
        TransformationFlip: QImageIOHandler = ...
        TransformationRotate180: QImageIOHandler = ...
        TransformationRotate90: QImageIOHandler = ...
        TransformationMirrorAndRotate90: QImageIOHandler = ...
        TransformationFlipAndRotate90: QImageIOHandler = ...
        TransformationRotate270: QImageIOHandler = ...

    class ImageOption(enum.Enum):
        Size: QImageIOHandler = ...
        ClipRect: QImageIOHandler = ...
        Description: QImageIOHandler = ...
        ScaledClipRect: QImageIOHandler = ...
        ScaledSize: QImageIOHandler = ...
        CompressionRatio: QImageIOHandler = ...
        Gamma: QImageIOHandler = ...
        Quality: QImageIOHandler = ...
        Name: QImageIOHandler = ...
        SubType: QImageIOHandler = ...
        IncrementalReading: QImageIOHandler = ...
        Endianness: QImageIOHandler = ...
        Animation: QImageIOHandler = ...
        BackgroundColor: QImageIOHandler = ...
        SupportedSubTypes: QImageIOHandler = ...
        OptimizedWrite: QImageIOHandler = ...
        ProgressiveScanWrite: QImageIOHandler = ...
        ImageTransformation: QImageIOHandler = ...

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#QImageIOHandler

        **QImageIOHandler::QImageIOHandler()**

        Constructs a QImageIOHandler object.
        """
        ...

    def currentImageRect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#currentImageRect

        **[virtual] QRect QImageIOHandler::currentImageRect() const**

        Returns the rect of the current image. If no rect is defined for the
        image, and empty QRect() is returned.

        This function is useful for animations, where only parts of the frame
        may be updated at a time.
        """
        ...

    def currentImageNumber(self) -> int:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#currentImageNumber

        **[virtual] int QImageIOHandler::currentImageNumber() const**

        For image formats that support animation, this function returns the
        sequence number of the current image in the animation. If this function
        is called before any image is **read** (), -1 is returned. The number of
        the first image in the sequence is 0.

        If the image format does not support animation, 0 is returned.

        **See also** **read** ().
        """
        ...

    def nextImageDelay(self) -> int:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#nextImageDelay

        **[virtual] int QImageIOHandler::nextImageDelay() const**

        For image formats that support animation, this function returns the
        number of milliseconds to wait until reading the next image. If the
        image format does not support animation, 0 is returned.
        """
        ...

    def imageCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#imageCount

        **[virtual] int QImageIOHandler::imageCount() const**

        For image formats that support animation, this function returns the
        number of images in the animation. If the image format does not support
        animation, or if it is unable to determine the number of images, 0 is
        returned.

        The default implementation returns 1 if **canRead** () returns `true`;
        otherwise 0 is returned.
        """
        ...

    def loopCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#loopCount

        **[virtual] int QImageIOHandler::loopCount() const**

        For image formats that support animation, this function returns the
        number of times the animation should loop. If the image format does not
        support animation, 0 is returned.
        """
        ...

    def jumpToImage(self, imageNumber: int) -> bool:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#jumpToImage

        **[virtual] bool QImageIOHandler::jumpToImage(int imageNumber )**

        For image formats that support animation, this function jumps to the
        image whose sequence number is **imageNumber**. The next call to
        **read** () will attempt to read this image.

        The default implementation does nothing, and returns `false`.
        """
        ...

    def jumpToNextImage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#jumpToNextImage

        **[virtual] bool QImageIOHandler::jumpToNextImage()**

        For image formats that support animation, this function jumps to the
        next image.

        The default implementation does nothing, and returns `false`.
        """
        ...

    def supportsOption(self, option: "QImageIOHandler.ImageOption") -> bool:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#supportsOption

        **[virtual] bool
        QImageIOHandler::supportsOption(QImageIOHandler::ImageOption option )
        const**

        Returns `true` if the **QImageIOHandler**  supports the option
        **option** ; otherwise returns `false`. For example, if the
        **QImageIOHandler**  supports the **Size**  option, supportsOption(Size)
        must return true.

        **See also** **setOption** () and **option** ().
        """
        ...

    def setOption(
        self, option: "QImageIOHandler.ImageOption", value: typing.Any
    ) -> None:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#setOption

        **[virtual] void QImageIOHandler::setOption(QImageIOHandler::ImageOption
        option , const QVariant & value )**

        Sets the option **option** with the value **value**.

        **See also** **option** () and **ImageOption** .
        """
        ...

    def option(self, option: "QImageIOHandler.ImageOption") -> typing.Any:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#option

        **[virtual] QVariant
        QImageIOHandler::option(QImageIOHandler::ImageOption option ) const**

        Returns the value assigned to **option** as a **QVariant** . The type of
        the value depends on the option. For example, option(Size) returns a
        **QSize**  variant.

        **See also** **setOption** () and **supportsOption** ().
        """
        ...

    def write(self, image: QImage) -> bool:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#write

        **[virtual] bool QImageIOHandler::write(const QImage & image )**

        Writes the image **image** to the assigned device. Returns `true` on
        success; otherwise returns `false`.

        The default implementation does nothing, and simply returns `false`.
        """
        ...

    def read(self, image: QImage) -> bool:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#read

        **[pure virtual] bool QImageIOHandler::read(QImage * image )**

        Read an image from the device, and stores it in **image**. Returns
        `true` if the image is successfully read; otherwise returns false.

        For image formats that support incremental loading, and for animation
        formats, the image handler can assume that **image** points to the
        previous frame.

        **See also** **canRead** ().
        """
        ...

    def canRead(self) -> bool:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#canRead

        **[pure virtual] bool QImageIOHandler::canRead() const**

        Returns `true` if an image can be read from the device (i.e., the image
        format is supported, the device can be read from and the initial header
        information suggests that the image can be read); otherwise returns
        `false`.

        When reimplementing canRead(), make sure that the I/O device (**device**
        ()) is left in its original state (e.g., by using peek() rather than
        **read** ()).

        **See also** **read** () and **QIODevice::peek** ().
        """
        ...

    def format(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#format

        **QByteArray QImageIOHandler::format() const**

        Returns the format that is currently assigned to **QImageIOHandler** .
        If no format has been assigned, an empty string is returned.

        **See also** **setFormat** ().
        """
        ...

    def setFormat(self, format: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#setFormat

        **void QImageIOHandler::setFormat(const QByteArray & format )**

        Sets the format of the **QImageIOHandler**  to **format**. The format is
        most useful for handlers that support multiple image formats.

        **See also** **format** ().
        """
        ...

    def device(self) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#device

        **QIODevice *QImageIOHandler::device() const**

        Returns the device currently assigned to the **QImageIOHandler** . If
        not device has been assigned, `nullptr` is returned.

        **See also** **setDevice** ().
        """
        ...

    def setDevice(self, device: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qimageiohandler.html#setDevice

        **void QImageIOHandler::setDevice(QIODevice * device )**

        Sets the device of the **QImageIOHandler**  to **device**. The image
        handler will use this device when reading and writing images.

        The device can only be set once and must be set before calling
        **canRead** (), **read** (), **write** (), etc. If you need to read
        multiple files, construct multiple instances of the appropriate
        **QImageIOHandler**  subclass.

        **See also** **device** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QTableView(QAbstractItemView):
    """
    https://doc.qt.io/qt-6/qtableview.html

    **Detailed Description**

    ![](images/windows-tableview.png)

    A QTableView implements a table view that displays items from a model. This
    class is used to provide standard tables that were previously provided by
    the QTable class, but using the more flexible approach provided by Qt's
    model/view architecture.

    The QTableView class is one of the **Model/View Classes**  and is part of
    Qt's **model/view framework** .

    QTableView implements the interfaces defined by the **QAbstractItemView**
    class to allow it to display data provided by models derived from the
    **QAbstractItemModel**  class.

    **Navigation**

    You can navigate the cells in the table by clicking on a cell with the
    mouse, or by using the arrow keys. Because QTableView enables
    **tabKeyNavigation**  by default, you can also hit Tab and Backtab to move
    from cell to cell.

    **Visual Appearance**

    The table has a vertical header that can be obtained using the
    **verticalHeader** () function, and a horizontal header that is available
    through the **horizontalHeader** () function. The height of each row in the
    table can be found by using **rowHeight** (); similarly, the width of
    columns can be found using **columnWidth** (). Since both of these are plain
    widgets, you can hide either of them using their **hide** () functions.

    Rows and columns can be hidden and shown with **hideRow** (), **hideColumn**
    (), **showRow** (), and **showColumn** (). They can be selected with
    **selectRow** () and **selectColumn** (). The table will show a grid
    depending on the **showGrid**  property.

    The items shown in a table view, like those in the other item views, are
    rendered and edited using standard **delegates** . However, for some tasks
    it is sometimes useful to be able to insert widgets in a table instead.
    Widgets are set for particular indexes with the **setIndexWidget** ()
    function, and later retrieved with **indexWidget** ().

    ![](images/qtableview-resized.png)By default, the cells in a table do not
    expand to fill the available space.

    You can make the cells fill the
    available space by stretching the last header section. Access the relevant
    header using **horizontalHeader** () or **verticalHeader** () and set the
    header's **stretchLastSection**  property.

    To distribute the available
    space according to the space requirement of each column or row, call the
    view's **resizeColumnsToContents** () or **resizeRowsToContents** ()
    functions.

    **Coordinate Systems**

    For some specialized forms of tables it is useful to be able to convert
    between row and column indexes and widget coordinates. The **rowAt** ()
    function provides the y-coordinate within the view of the specified row; the
    row index can be used to obtain a corresponding y-coordinate with
    **rowViewportPosition** (). The **columnAt** () and
    **columnViewportPosition** () functions provide the equivalent conversion
    operations between x-coordinates and column indexes.

    **See also** **QTableWidget** , **View Classes** , **QAbstractItemModel** ,
    **QAbstractItemView** , **Chart Example** , **Pixelator Example** , and
    **Table Model Example** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#QTableView

        **QTableView::QTableView(QWidget * parent = nullptr)**

        Constructs a table view with a **parent** to represent the data.

        **See also** **QAbstractItemModel** .
        """
        ...

    def initViewItemOption(self, option: QStyleOptionViewItem) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#initViewItemOption

        **[override virtual protected] void
        QTableView::initViewItemOption(QStyleOptionViewItem * option ) const**

        Reimplements:
        **QAbstractItemView::initViewItemOption(QStyleOptionViewItem *option)
        const** .
        """
        ...

    def currentChanged(
        self, current: QtCore.QModelIndex, previous: QtCore.QModelIndex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#currentChanged

        **[override virtual protected] void QTableView::currentChanged(const
        QModelIndex & current , const QModelIndex & previous )**

        Reimplements: **QAbstractItemView::currentChanged** (const QModelIndex
        &current, const QModelIndex &previous).
        """
        ...

    def selectionChanged(
        self, selected: QtCore.QItemSelection, deselected: QtCore.QItemSelection
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#selectionChanged

        **[override virtual protected] void QTableView::selectionChanged(const
        QItemSelection & selected , const QItemSelection & deselected )**

        Reimplements: **QAbstractItemView::selectionChanged** (const
        QItemSelection &selected, const QItemSelection &deselected).
        """
        ...

    def clearSpans(self) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#clearSpans

        **void QTableView::clearSpans()**

        Removes all row and column spans in the table view.

        **See also** **setSpan** ().
        """
        ...

    def isCornerButtonEnabled(self) -> bool:
        ...

    def setCornerButtonEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#cornerButtonEnabled-prop

        **cornerButtonEnabled : bool**

        This property holds whether the button in the top-left corner is enabled

        If this property is `true` then button in the top-left corner of the
        table view is enabled. Clicking on this button will select all the cells
        in the table view.

        This property is `true` by default.

        **Access functions:**

        bool **isCornerButtonEnabled** () const
        void
        **setCornerButtonEnabled** (bool **enable** )
        """
        ...

    def wordWrap(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtableview.html#wordWrap-prop

        **wordWrap : bool**

        This property holds the item text word-wrapping policy

        If this property is `true` then the item text is wrapped where necessary
        at word-breaks; otherwise it is not wrapped at all. This property is
        `true` by default.

        Note that even of wrapping is enabled, the cell will not be expanded to
        fit all text. Ellipsis will be inserted according to the current
        **textElideMode** .

        **Access functions:**

        bool **wordWrap** () const
        void **setWordWrap** (bool **on** )

        **Member Function Documentation**
        """
        ...

    def setWordWrap(self, on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#wordWrap-prop

        **wordWrap : bool**

        This property holds the item text word-wrapping policy

        If this property is `true` then the item text is wrapped where necessary
        at word-breaks; otherwise it is not wrapped at all. This property is
        `true` by default.

        Note that even of wrapping is enabled, the cell will not be expanded to
        fit all text. Ellipsis will be inserted according to the current
        **textElideMode** .

        **Access functions:**

        bool **wordWrap** () const
        void **setWordWrap** (bool **on** )

        **Member Function Documentation**
        """
        ...

    def sortByColumn(self, column: int, order: QtCore.Qt.SortOrder) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#sortByColumn

        **[slot] void QTableView::sortByColumn(int column , Qt::SortOrder order
        )**

        Sorts the model by the values in the given **column** and **order**.

        **column** may be -1, in which case no sort indicator will be shown and
        the model will return to its natural, unsorted order. Note that not all
        models support this and may even crash in this case.

        **See also** **sortingEnabled** .
        """
        ...

    def columnSpan(self, row: int, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qtableview.html#columnSpan

        **int QTableView::columnSpan(int row , int column ) const**

        Returns the column span of the table element at ( **row** , **column**
        ). The default is 1.

        **See also** **setSpan** () and **rowSpan** ().
        """
        ...

    def rowSpan(self, row: int, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qtableview.html#rowSpan

        **int QTableView::rowSpan(int row , int column ) const**

        Returns the row span of the table element at ( **row** , **column** ).
        The default is 1.

        **See also** **setSpan** () and **columnSpan** ().
        """
        ...

    def setSpan(self, row: int, column: int, rowSpan: int, columnSpan: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#setSpan

        **void QTableView::setSpan(int row , int column , int rowSpanCount , int
        columnSpanCount )**

        Sets the span of the table element at ( **row** , **column** ) to the
        number of rows and columns specified by ( **rowSpanCount** ,
        **columnSpanCount** ).

        **See also** **rowSpan** () and **columnSpan** ().
        """
        ...

    def isSortingEnabled(self) -> bool:
        ...

    def setSortingEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#setSortingEnabled

        **void QTableView::setSortingEnabled(bool enable )**

        If **enable** is true, enables sorting for the table and immediately
        trigger a call to **sortByColumn** () with the current sort section and
        order

        **Note:** Setter function for property **sortingEnabled** .

        **See also** **isSortingEnabled** ().
        """
        ...

    def viewportSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtableview.html#viewportSizeHint

        **[override virtual protected] QSize QTableView::viewportSizeHint()
        const**

        Reimplements: **QAbstractItemView::viewportSizeHint() const** .
        """
        ...

    def isIndexHidden(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qtableview.html#isIndexHidden

        **[override virtual protected] bool QTableView::isIndexHidden(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemView::isIndexHidden(const QModelIndex
        &index) const** .
        """
        ...

    def horizontalScrollbarAction(self, action: int) -> None:
        ...

    def verticalScrollbarAction(self, action: int) -> None:
        ...

    def sizeHintForColumn(self, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qtableview.html#sizeHintForColumn

        **[override virtual protected] int QTableView::sizeHintForColumn(int
        column ) const**

        Reimplements: **QAbstractItemView::sizeHintForColumn(int column) const**
        .

        Returns the size hint for the given **column** 's width or -1 if there
        is no model.

        If you need to set the width of a given column to a fixed value, call
        **QHeaderView::resizeSection** () on the table's horizontal header.

        If you reimplement this function in a subclass, note that the value you
        return will be used when **resizeColumnToContents** () or
        **QHeaderView::resizeSections** () is called. If a larger column width
        is required by either the horizontal header or the item delegate, the
        larger width will be used instead.

        **See also** **QWidget::sizeHint** , **horizontalHeader** (), and
        **QHeaderView::resizeContentsPrecision** ().
        """
        ...

    def sizeHintForRow(self, row: int) -> int:
        """
        https://doc.qt.io/qt-6/qtableview.html#sizeHintForRow

        **[override virtual protected] int QTableView::sizeHintForRow(int row )
        const**

        Reimplements: **QAbstractItemView::sizeHintForRow(int row) const** .

        Returns the size hint for the given **row** 's height or -1 if there is
        no model.

        If you need to set the height of a given row to a fixed value, call
        **QHeaderView::resizeSection** () on the table's vertical header.

        If you reimplement this function in a subclass, note that the value you
        return is only used when **resizeRowToContents** () is called. In that
        case, if a larger row height is required by either the vertical header
        or the item delegate, that width will be used instead.

        **See also** **QWidget::sizeHint** , **verticalHeader** (), and
        **QHeaderView::resizeContentsPrecision** ().
        """
        ...

    def updateGeometries(self) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#updateGeometries

        **[override virtual protected] void QTableView::updateGeometries()**

        Reimplements: **QAbstractItemView::updateGeometries** ().
        """
        ...

    def selectedIndexes(self) -> typing.List[QtCore.QModelIndex]:
        """
        https://doc.qt.io/qt-6/qtableview.html#selectedIndexes

        **[override virtual protected] QModelIndexList
        QTableView::selectedIndexes() const**

        Reimplements: **QAbstractItemView::selectedIndexes() const** .
        """
        ...

    def visualRegionForSelection(
        self, selection: QtCore.QItemSelection
    ) -> QtGui.QRegion:
        """
        https://doc.qt.io/qt-6/qtableview.html#visualRegionForSelection

        **[override virtual protected] QRegion
        QTableView::visualRegionForSelection(const QItemSelection & selection )
        const**

        Reimplements: **QAbstractItemView::visualRegionForSelection(const
        QItemSelection &selection) const** .

        Returns the rectangle from the viewport of the items in the given
        **selection**.

        Since 4.7, the returned region only contains rectangles intersecting (or
        included in) the viewport.
        """
        ...

    def setSelection(
        self, rect: QtCore.QRect, command: QtCore.QItemSelectionModel.SelectionFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#setSelection

        **[override virtual protected] void QTableView::setSelection(const QRect
        & rect , QItemSelectionModel::SelectionFlags flags )**

        Reimplements: **QAbstractItemView::setSelection** (const QRect &rect,
        QItemSelectionModel::SelectionFlags flags).

        Selects the items within the given **rect** and in accordance with the
        specified selection **flags**.
        """
        ...

    def moveCursor(
        self,
        cursorAction: QAbstractItemView.CursorAction,
        modifiers: QtCore.Qt.KeyboardModifier,
    ) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qtableview.html#moveCursor

        **[override virtual protected] QModelIndex
        QTableView::moveCursor(QAbstractItemView::CursorAction cursorAction ,
        Qt::KeyboardModifiers modifiers )**

        Reimplements: **QAbstractItemView::moveCursor**
        (QAbstractItemView::CursorAction cursorAction, Qt::KeyboardModifiers
        modifiers).

        Moves the cursor in accordance with the given **cursorAction** , using
        the information provided by the **modifiers**.

        **See also** **QAbstractItemView::CursorAction** .
        """
        ...

    def verticalOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qtableview.html#verticalOffset

        **[override virtual protected] int QTableView::verticalOffset() const**

        Reimplements: **QAbstractItemView::verticalOffset() const** .

        Returns the vertical offset of the items in the table view.

        Note that the table view uses the vertical header section positions to
        determine the positions of rows in the view.

        **See also** **horizontalOffset** ().
        """
        ...

    def horizontalOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qtableview.html#horizontalOffset

        **[override virtual protected] int QTableView::horizontalOffset()
        const**

        Reimplements: **QAbstractItemView::horizontalOffset() const** .

        Returns the horizontal offset of the items in the table view.

        Note that the table view uses the horizontal header section positions to
        determine the positions of columns in the view.

        **See also** **verticalOffset** ().
        """
        ...

    def timerEvent(self, event: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#timerEvent

        **[override virtual protected] void QTableView::timerEvent(QTimerEvent *
        event )**

        Reimplements: **QAbstractItemView::timerEvent** (QTimerEvent *event).
        """
        ...

    def paintEvent(self, e: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#paintEvent

        **[override virtual protected] void QTableView::paintEvent(QPaintEvent *
        event )**

        Reimplements: **QAbstractScrollArea::paintEvent** (QPaintEvent *event).

        Paints the table on receipt of the given paint event **event**.
        """
        ...

    def scrollContentsBy(self, dx: int, dy: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#scrollContentsBy

        **[override virtual protected] void QTableView::scrollContentsBy(int dx
        , int dy )**

        Reimplements: **QAbstractScrollArea::scrollContentsBy** (int dx, int
        dy).

        Scroll the contents of the table view by ( **dx** , **dy** ).
        """
        ...

    def columnCountChanged(self, oldCount: int, newCount: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#columnCountChanged

        **[protected slot] void QTableView::columnCountChanged(int oldCount ,
        int newCount )**

        This slot is called whenever columns are added or deleted. The previous
        number of columns is specified by **oldCount** , and the new number of
        columns is specified by **newCount**.
        """
        ...

    def rowCountChanged(self, oldCount: int, newCount: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#rowCountChanged

        **[protected slot] void QTableView::rowCountChanged(int oldCount , int
        newCount )**

        This slot is called whenever rows are added or deleted. The previous
        number of rows is specified by **oldCount** , and the new number of rows
        is specified by **newCount**.
        """
        ...

    def columnResized(self, column: int, oldWidth: int, newWidth: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#columnResized

        **[protected slot] void QTableView::columnResized(int column , int
        oldWidth , int newWidth )**

        This slot is called to change the width of the given **column**. The old
        width is specified by **oldWidth** , and the new width by **newWidth**.

        **See also** **rowResized** ().
        """
        ...

    def rowResized(self, row: int, oldHeight: int, newHeight: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#rowResized

        **[protected slot] void QTableView::rowResized(int row , int oldHeight ,
        int newHeight )**

        This slot is called to change the height of the given **row**. The old
        height is specified by **oldHeight** , and the new height by
        **newHeight**.

        **See also** **columnResized** ().
        """
        ...

    def columnMoved(self, column: int, oldIndex: int, newIndex: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#columnMoved

        **[protected slot] void QTableView::columnMoved(int column , int
        oldIndex , int newIndex )**

        This slot is called to change the index of the given **column** in the
        table view. The old index is specified by **oldIndex** , and the new
        index by **newIndex**.

        **See also** **rowMoved** ().
        """
        ...

    def rowMoved(self, row: int, oldIndex: int, newIndex: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#rowMoved

        **[protected slot] void QTableView::rowMoved(int row , int oldIndex ,
        int newIndex )**

        This slot is called to change the index of the given **row** in the
        table view. The old index is specified by **oldIndex** , and the new
        index by **newIndex**.

        **See also** **columnMoved** ().
        """
        ...

    def resizeColumnsToContents(self) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#resizeColumnsToContents

        **[slot] void QTableView::resizeColumnsToContents()**

        Resizes all columns based on the size hints of the delegate used to
        render each item in the columns.

        **See also** **resizeColumnToContents** (), **sizeHintForColumn** (),
        and **QHeaderView::resizeContentsPrecision** ().
        """
        ...

    def resizeColumnToContents(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#resizeColumnToContents

        **[slot] void QTableView::resizeColumnToContents(int column )**

        Resizes the given **column** based on the size hints of the delegate
        used to render each item in the column.

        **Note:** Only visible columns will be resized. Reimplement
        **sizeHintForColumn** () to resize hidden columns as well.

        **See also** **resizeColumnsToContents** (), **sizeHintForColumn** (),
        and **QHeaderView::resizeContentsPrecision** ().
        """
        ...

    def resizeRowsToContents(self) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#resizeRowsToContents

        **[slot] void QTableView::resizeRowsToContents()**

        Resizes all rows based on the size hints of the delegate used to render
        each item in the rows.

        **See also** **resizeRowToContents** (), **sizeHintForRow** (), and
        **QHeaderView::resizeContentsPrecision** ().
        """
        ...

    def resizeRowToContents(self, row: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#resizeRowToContents

        **[slot] void QTableView::resizeRowToContents(int row )**

        Resizes the given **row** based on the size hints of the delegate used
        to render each item in the row.

        **See also** **resizeRowsToContents** (), **sizeHintForRow** (), and
        **QHeaderView::resizeContentsPrecision** ().
        """
        ...

    def showColumn(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#showColumn

        **[slot] void QTableView::showColumn(int column )**

        Show the given **column**.

        **See also** **hideColumn** () and **showRow** ().
        """
        ...

    def showRow(self, row: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#showRow

        **[slot] void QTableView::showRow(int row )**

        Show the given **row**.

        **See also** **hideRow** () and **showColumn** ().
        """
        ...

    def hideColumn(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#hideColumn

        **[slot] void QTableView::hideColumn(int column )**

        Hide the given **column**.

        **See also** **showColumn** () and **hideRow** ().
        """
        ...

    def hideRow(self, row: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#hideRow

        **[slot] void QTableView::hideRow(int row )**

        Hide the given **row**.

        **See also** **showRow** () and **hideColumn** ().
        """
        ...

    def selectColumn(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#selectColumn

        **[slot] void QTableView::selectColumn(int column )**

        Selects the given **column** in the table view if the current
        SelectionMode and SelectionBehavior allows columns to be selected.

        **See also** **selectRow** ().
        """
        ...

    def selectRow(self, row: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#selectRow

        **[slot] void QTableView::selectRow(int row )**

        Selects the given **row** in the table view if the current SelectionMode
        and SelectionBehavior allows rows to be selected.

        **See also** **selectColumn** ().
        """
        ...

    def indexAt(self, p: QtCore.QPoint) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qtableview.html#indexAt

        **[override virtual] QModelIndex QTableView::indexAt(const QPoint & pos
        ) const**

        Reimplements: **QAbstractItemView::indexAt(const QPoint &point) const**
        .

        Returns the index position of the model item corresponding to the table
        item at position **pos** in contents coordinates.
        """
        ...

    def scrollTo(
        self, index: QtCore.QModelIndex, hint: QAbstractItemView.ScrollHint = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#scrollTo

        **[override virtual] void QTableView::scrollTo(const QModelIndex & index
        , QAbstractItemView::ScrollHint hint = EnsureVisible)**

        Reimplements: **QAbstractItemView::scrollTo** (const QModelIndex &index,
        QAbstractItemView::ScrollHint hint).

        Makes sure that the given **index** is visible in the table view,
        scrolling if necessary.
        """
        ...

    def visualRect(self, index: QtCore.QModelIndex) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qtableview.html#visualRect

        **[override virtual] QRect QTableView::visualRect(const QModelIndex &
        index ) const**

        Reimplements: **QAbstractItemView::visualRect(const QModelIndex &index)
        const** .

        Returns the rectangle on the viewport occupied by the given **index**.
        If the index is hidden in the view it will return a null **QRect** .
        """
        ...

    def setGridStyle(self, style: QtCore.Qt.PenStyle) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#gridStyle-prop

        **gridStyle : Qt::PenStyle**

        This property holds the pen style used to draw the grid.

        This property holds the style used when drawing the grid (see
        **showGrid** ).

        **Access functions:**

        Qt::PenStyle **gridStyle** () const
        void **setGridStyle**
        (Qt::PenStyle **style** )
        """
        ...

    def gridStyle(self) -> QtCore.Qt.PenStyle:
        """
        https://doc.qt.io/qt-6/qtableview.html#gridStyle-prop

        **gridStyle : Qt::PenStyle**

        This property holds the pen style used to draw the grid.

        This property holds the style used when drawing the grid (see
        **showGrid** ).

        **Access functions:**

        Qt::PenStyle **gridStyle** () const
        void **setGridStyle**
        (Qt::PenStyle **style** )
        """
        ...

    def setShowGrid(self, show: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#showGrid-prop

        **showGrid : bool**

        This property holds whether the grid is shown

        If this property is `true` a grid is drawn for the table; if the
        property is `false`, no grid is drawn. The default value is true.

        **Access functions:**

        bool **showGrid** () const
        void **setShowGrid** (bool **show** )
        """
        ...

    def showGrid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtableview.html#showGrid-prop

        **showGrid : bool**

        This property holds whether the grid is shown

        If this property is `true` a grid is drawn for the table; if the
        property is `false`, no grid is drawn. The default value is true.

        **Access functions:**

        bool **showGrid** () const
        void **setShowGrid** (bool **show** )
        """
        ...

    def setColumnHidden(self, column: int, hide: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#setColumnHidden

        **void QTableView::setColumnHidden(int column , bool hide )**

        If **hide** is true the given **column** will be hidden; otherwise it
        will be shown.

        **See also** **isColumnHidden** () and **setRowHidden** ().
        """
        ...

    def isColumnHidden(self, column: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtableview.html#isColumnHidden

        **bool QTableView::isColumnHidden(int column ) const**

        Returns `true` if the given **column** is hidden; otherwise returns
        `false`.

        **See also** **isRowHidden** ().
        """
        ...

    def setRowHidden(self, row: int, hide: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#setRowHidden

        **void QTableView::setRowHidden(int row , bool hide )**

        If **hide** is true **row** will be hidden, otherwise it will be shown.

        **See also** **isRowHidden** () and **setColumnHidden** ().
        """
        ...

    def isRowHidden(self, row: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtableview.html#isRowHidden

        **bool QTableView::isRowHidden(int row ) const**

        Returns `true` if the given **row** is hidden; otherwise returns
        `false`.

        **See also** **isColumnHidden** ().
        """
        ...

    def columnAt(self, x: int) -> int:
        """
        https://doc.qt.io/qt-6/qtableview.html#columnAt

        **int QTableView::columnAt(int x ) const**

        Returns the column in which the given x-coordinate, **x** , in contents
        coordinates is located.

        **Note:** This function returns -1 if the given coordinate is not valid
        (has no column).

        **See also** **rowAt** ().
        """
        ...

    def columnWidth(self, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qtableview.html#columnWidth

        **int QTableView::columnWidth(int column ) const**

        Returns the width of the given **column**.

        **See also** **setColumnWidth** (), **resizeColumnToContents** (), and
        **rowHeight** ().
        """
        ...

    def setColumnWidth(self, column: int, width: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#setColumnWidth

        **void QTableView::setColumnWidth(int column , int width )**

        Sets the width of the given **column** to be **width**.

        **See also** **columnWidth** ().
        """
        ...

    def columnViewportPosition(self, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qtableview.html#columnViewportPosition

        **int QTableView::columnViewportPosition(int column ) const**

        Returns the x-coordinate in contents coordinates of the given
        **column**.
        """
        ...

    def rowAt(self, y: int) -> int:
        """
        https://doc.qt.io/qt-6/qtableview.html#rowAt

        **int QTableView::rowAt(int y ) const**

        Returns the row in which the given y-coordinate, **y** , in contents
        coordinates is located.

        **Note:** This function returns -1 if the given coordinate is not valid
        (has no row).

        **See also** **columnAt** ().
        """
        ...

    def rowHeight(self, row: int) -> int:
        """
        https://doc.qt.io/qt-6/qtableview.html#rowHeight

        **int QTableView::rowHeight(int row ) const**

        Returns the height of the given **row**.

        **See also** **setRowHeight** (), **resizeRowToContents** (), and
        **columnWidth** ().
        """
        ...

    def setRowHeight(self, row: int, height: int) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#setRowHeight

        **void QTableView::setRowHeight(int row , int height )**

        Sets the height of the given **row** to be **height**.

        **See also** **rowHeight** ().
        """
        ...

    def rowViewportPosition(self, row: int) -> int:
        """
        https://doc.qt.io/qt-6/qtableview.html#rowViewportPosition

        **int QTableView::rowViewportPosition(int row ) const**

        Returns the y-coordinate in contents coordinates of the given **row**.
        """
        ...

    def setVerticalHeader(self, header: QHeaderView) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#setVerticalHeader

        **void QTableView::setVerticalHeader(QHeaderView * header )**

        Sets the widget to use for the vertical header to **header**.

        **See also** **verticalHeader** () and **setHorizontalHeader** ().
        """
        ...

    def setHorizontalHeader(self, header: QHeaderView) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#setHorizontalHeader

        **void QTableView::setHorizontalHeader(QHeaderView * header )**

        Sets the widget to use for the horizontal header to **header**.

        **See also** **horizontalHeader** () and **setVerticalHeader** ().
        """
        ...

    def verticalHeader(self) -> QHeaderView:
        """
        https://doc.qt.io/qt-6/qtableview.html#verticalHeader

        **QHeaderView *QTableView::verticalHeader() const**

        Returns the table view's vertical header.

        **See also** **setVerticalHeader** (), **horizontalHeader** (), and
        **QAbstractItemModel::headerData** ().
        """
        ...

    def horizontalHeader(self) -> QHeaderView:
        """
        https://doc.qt.io/qt-6/qtableview.html#horizontalHeader

        **QHeaderView *QTableView::horizontalHeader() const**

        Returns the table view's horizontal header.

        **See also** **setHorizontalHeader** (), **verticalHeader** (), and
        **QAbstractItemModel::headerData** ().
        """
        ...

    def setSelectionModel(self, selectionModel: QtCore.QItemSelectionModel) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#setSelectionModel

        **[override virtual] void
        QTableView::setSelectionModel(QItemSelectionModel * selectionModel )**

        Reimplements: **QAbstractItemView::setSelectionModel**
        (QItemSelectionModel *selectionModel).
        """
        ...

    def setRootIndex(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#setRootIndex

        **[override virtual] void QTableView::setRootIndex(const QModelIndex &
        index )**

        Reimplements: **QAbstractItemView::setRootIndex** (const QModelIndex
        &index).
        """
        ...

    def setModel(self, model: QtCore.QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qtableview.html#setModel

        **[override virtual] void QTableView::setModel(QAbstractItemModel *
        model )**

        Reimplements: **QAbstractItemView::setModel** (QAbstractItemModel
        *model).
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQuick import *
import enum


class QSGGeometry(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qsggeometry.html

    **Detailed Description**

    The QSGGeometry class stores the geometry of the primitives rendered with
    the scene graph. It contains vertex data and optionally index data. The mode
    used to draw the geometry, also called primitive topology, is specified with
    **setDrawingMode** ().

    Vertices can be as simple as points defined by x and y values or can be more
    complex where each vertex contains a normal, texture coordinates and a 3D
    position. The **QSGGeometry::AttributeSet**  is used to describe how the
    vertex data is built up. The attribute set can only be specified on
    construction. The QSGGeometry class provides a few convenience attributes
    and attribute sets by default. The **defaultAttributes_Point2D** () function
    returns an attribute set to be used in normal solid color rectangles, while
    the **defaultAttributes_TexturedPoint2D**  function returns attributes to be
    used for textured 2D geometry. The vertex data is internally stored as a
    `void *` and is accessible with the **vertexData** () function. Convenience
    accessors for the common attribute sets are available with
    **vertexDataAsPoint2D** () and **vertexDataAsTexturedPoint2D** (). Vertex
    data is allocated by passing a vertex count to the constructor or by calling
    **allocate** () later.

    The QSGGeometry can optionally contain indices of either unsigned 32-bit,
    unsigned 16-bit, or unsigned 8-bit integers. The index type must be
    specified during construction and cannot be changed.

    Below is a snippet illustrating how a geometry composed of position and
    color vertices can be built.

    struct MyPoint2D {
            float x;
            float y;
            float r;
    float g;
            float b;
            float a;

            void set(float x_,
    float y_, float r_, float g_, float b_, float a_) {
                x = x_;
    y = y_;
                r = r_;
                g = g_;
                b = b_;
    a = a_;
            }
        };

        **QSGGeometry** ::Attribute
    MyPoint2D_Attributes[] = {
            **QSGGeometry** ::Attribute::create(0, 2,
    FloatType, true),
            **QSGGeometry** ::Attribute::create(1, 4,
    FloatType, false)
        };

        **QSGGeometry** ::AttributeSet
    MyPoint2D_AttributeSet = {
            2,
            sizeof(MyPoint2D),
    MyPoint2D_Attributes
        };

        ...

        geometry = new
    **QSGGeometry** (MyPoint2D_AttributeSet, 2);
    geometry->setDrawingMode(DrawLines);

        MyPoint2D *vertices =
    static_cast<MyPoint2D *>(geometry->vertexData());
        vertices[0].set(0, 0,
    1, 0, 0, 1);
        vertices[1].set(width(), height(), 0, 0, 1, 1);

    The QSGGeometry is a software buffer and client-side in terms of accelerated
    rendering, as the buffers used in 2D graphics typically consist of many
    small buffers that change every frame and do not benefit from being uploaded
    to graphics memory. However, the QSGGeometry supports hinting to the
    renderer that a buffer should be uploaded using the **setVertexDataPattern**
    () and **setIndexDataPattern** () functions. Whether this hint is respected
    or not is implementation specific.

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.

    **See also** **QSGGeometryNode**  and **Scene Graph - Custom Geometry** .
    """

    class Type(enum.Enum):
        ByteType: QSGGeometry = ...
        UnsignedByteType: QSGGeometry = ...
        ShortType: QSGGeometry = ...
        UnsignedShortType: QSGGeometry = ...
        IntType: QSGGeometry = ...
        UnsignedIntType: QSGGeometry = ...
        FloatType: QSGGeometry = ...
        Bytes2Type: QSGGeometry = ...
        Bytes3Type: QSGGeometry = ...
        Bytes4Type: QSGGeometry = ...
        DoubleType: QSGGeometry = ...

    class DrawingMode(enum.IntEnum):
        DrawPoints: QSGGeometry = ...
        DrawLines: QSGGeometry = ...
        DrawLineLoop: QSGGeometry = ...
        DrawLineStrip: QSGGeometry = ...
        DrawTriangles: QSGGeometry = ...
        DrawTriangleStrip: QSGGeometry = ...
        DrawTriangleFan: QSGGeometry = ...

    class AttributeType(enum.Enum):
        UnknownAttribute: QSGGeometry = ...
        PositionAttribute: QSGGeometry = ...
        ColorAttribute: QSGGeometry = ...
        TexCoordAttribute: QSGGeometry = ...
        TexCoord1Attribute: QSGGeometry = ...
        TexCoord2Attribute: QSGGeometry = ...

    class DataPattern(enum.Enum):
        AlwaysUploadPattern: QSGGeometry = ...
        StreamPattern: QSGGeometry = ...
        DynamicPattern: QSGGeometry = ...
        StaticPattern: QSGGeometry = ...

    class Attribute(PyQt6.sip.simplewrapper):
        attributeType = ...
        isVertexCoordinate: int = ...
        position: int = ...
        tupleSize: int = ...
        type: int = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QSGGeometry.Attribute") -> None:
            ...

        @staticmethod
        def createWithAttributeType(
            pos: int,
            tupleSize: int,
            primitiveType: int,
            attributeType: "QSGGeometry.AttributeType",
        ) -> "QSGGeometry.Attribute":
            ...

        @staticmethod
        def create(
            pos: int, tupleSize: int, primitiveType: int, isPosition: bool = ...
        ) -> "QSGGeometry.Attribute":
            ...

    class AttributeSet(PyQt6.sip.simplewrapper):
        attributes: PyQt6 = ...
        count: int = ...
        stride: int = ...

        def __init__(
            self,
            attributes: typing.Iterable["QSGGeometry.Attribute"],
            stride: int = ...,
        ) -> None:
            ...

    class Point2D(PyQt6.sip.simplewrapper):
        x: float = ...
        y: float = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QSGGeometry.Point2D") -> None:
            ...

        def set(self, nx: float, ny: float) -> None:
            ...

    class TexturedPoint2D(PyQt6.sip.simplewrapper):
        tx: float = ...
        ty: float = ...
        x: float = ...
        y: float = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QSGGeometry.TexturedPoint2D") -> None:
            ...

        def set(self, nx: float, ny: float, ntx: float, nty: float) -> None:
            ...

    class ColoredPoint2D(PyQt6.sip.simplewrapper):
        a: int = ...
        b: int = ...
        g: int = ...
        r: int = ...
        x: float = ...
        y: float = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QSGGeometry.ColoredPoint2D") -> None:
            ...

        def set(self, nx: float, ny: float, nr: int, ng: int, nb: int, na: int) -> None:
            ...

    def __init__(
        self,
        attribs: "QSGGeometry.AttributeSet",
        vertexCount: int,
        indexCount: int = ...,
        indexType: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#QSGGeometry

        **QSGGeometry::QSGGeometry(const QSGGeometry::AttributeSet & attributes
        , int vertexCount , int indexCount = 0, int indexType =
        UnsignedShortType)**

        Constructs a geometry object based on **attributes**.

        The object allocate space for **vertexCount** vertices based on the
        accumulated size in **attributes** and for **indexCount**.

        The **indexType** can be **UnsignedShortType**  or `UnsignedIntType`.
        Support for the latter depends on the graphics API implementation used
        at run time, and may not always be available.

        Geometry objects are constructed by default with **DrawTriangleStrip**
        as the drawing mode.

        The attribute structure is assumed to be POD and the geometry object
        assumes this will not go away. There is no memory management involved.
        """
        ...

    @staticmethod
    def updateColoredRectGeometry(g: "QSGGeometry", rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#updateColoredRectGeometry

        **[static] void QSGGeometry::updateColoredRectGeometry(QSGGeometry * g ,
        const QRectF & rect )**

        Updates the geometry **g** with the coordinates in **rect**.

        The function assumes the geometry object contains a single triangle
        strip of **QSGGeometry::ColoredPoint2D**  vertices
        """
        ...

    def sizeOfIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#sizeOfIndex

        **int QSGGeometry::sizeOfIndex() const**

        Returns the byte size of the index type.

        This value is either `2` when the index type is **UnsignedShortType** ,
        or `4` when the index type is **UnsignedIntType** .
        """
        ...

    def vertexDataAsColoredPoint2D(self) -> PyQt6.sip.array[QSGGeometry.ColoredPoint2D]:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#vertexDataAsColoredPoint2D

        **QSGGeometry::ColoredPoint2D
        *QSGGeometry::vertexDataAsColoredPoint2D()**

        Convenience function to access the vertex data as a mutable array of
        **QSGGeometry::ColoredPoint2D** .
        """
        ...

    def vertexDataAsTexturedPoint2D(
        self,
    ) -> PyQt6.sip.array[QSGGeometry.TexturedPoint2D]:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#vertexDataAsTexturedPoint2D

        **QSGGeometry::TexturedPoint2D
        *QSGGeometry::vertexDataAsTexturedPoint2D()**

        Convenience function to access the vertex data as a mutable array of
        **QSGGeometry::TexturedPoint2D** .
        """
        ...

    def vertexDataAsPoint2D(self) -> PyQt6.sip.array[QSGGeometry.Point2D]:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#vertexDataAsPoint2D

        **QSGGeometry::Point2D *QSGGeometry::vertexDataAsPoint2D()**

        Convenience function to access the vertex data as a mutable array of
        **QSGGeometry::Point2D** .
        """
        ...

    def indexDataAsUShort(self) -> PyQt6.sip.array[int]:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#indexDataAsUShort

        **quint16 *QSGGeometry::indexDataAsUShort()**

        Convenience function to access the index data as a mutable array of
        16-bit unsigned integers.
        """
        ...

    def indexDataAsUInt(self) -> PyQt6.sip.array[int]:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#indexDataAsUInt

        **uint *QSGGeometry::indexDataAsUInt()**

        Convenience function to access the index data as a mutable array of
        32-bit unsigned integers.
        """
        ...

    def setLineWidth(self, w: float) -> None:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#setLineWidth

        **void QSGGeometry::setLineWidth(float width )**

        Sets the line or point width to be used for this geometry to **width**.
        This property only applies to line width when the **drawingMode**  is
        **DrawLines** , **DrawLineStrip** , or **DrawLineLoop** . When
        supported, it also applies to point size when the **drawingMode**  is
        **DrawPoints** .

        **Note:** Support for point and line drawing may be limited at run time,
        depending on the platform and graphics API. For example, some APIs do
        not support point sprites and so setting a size other than 1 is not
        possible.

        **Note:** The width of `1.0` is always supported.

        **See also** **lineWidth** () and **drawingMode** ().
        """
        ...

    def lineWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#lineWidth

        **float QSGGeometry::lineWidth() const**

        Gets the current line or point width or to be used for this geometry.
        This property only applies to line width when the **drawingMode**  is
        **DrawLines** , DarwLineStrip, or **DrawLineLoop** . When supported, it
        also applies to point size when the **drawingMode**  is **DrawPoints** .

        The default value is `1.0`

        **Note:** Support for point and line drawing may be limited at run time,
        depending on the platform and graphics API. For example, some APIs do
        not support point sprites and so setting a size other than 1 is not
        possible.

        **Note:** The width of `1.0` is always supported.

        **See also** **setLineWidth** () and **drawingMode** ().
        """
        ...

    def markVertexDataDirty(self) -> None:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#markVertexDataDirty

        **void QSGGeometry::markVertexDataDirty()**

        Mark that the vertices in this geometry has changed and must be uploaded
        again.

        This function only has an effect when the usage pattern for vertices is
        StaticData and the renderer that renders this geometry uploads the
        geometry into Vertex Buffer Objects (VBOs).
        """
        ...

    def markIndexDataDirty(self) -> None:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#markIndexDataDirty

        **void QSGGeometry::markIndexDataDirty()**

        Mark that the vertices in this geometry has changed and must be uploaded
        again.

        This function only has an effect when the usage pattern for vertices is
        StaticData and the renderer that renders this geometry uploads the
        geometry into Vertex Buffer Objects (VBOs).
        """
        ...

    def vertexDataPattern(self) -> "QSGGeometry.DataPattern":
        """
        https://doc.qt.io/qt-6/qsggeometry.html#vertexDataPattern

        **QSGGeometry::DataPattern QSGGeometry::vertexDataPattern() const**

        Returns the usage pattern for vertices in this geometry. The default
        pattern is **AlwaysUploadPattern** .

        **See also** **setVertexDataPattern** ().
        """
        ...

    def setVertexDataPattern(self, p: "QSGGeometry.DataPattern") -> None:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#setVertexDataPattern

        **void QSGGeometry::setVertexDataPattern(QSGGeometry::DataPattern p )**

        Sets the usage pattern for vertices to **p**.

        The default is **AlwaysUploadPattern** . When set to anything other than
        the default, the user must call **markVertexDataDirty** () after
        changing the vertex data, in addition to calling **QSGNode::markDirty**
        () with **QSGNode::DirtyGeometry** .

        **See also** **vertexDataPattern** ().
        """
        ...

    def indexDataPattern(self) -> "QSGGeometry.DataPattern":
        """
        https://doc.qt.io/qt-6/qsggeometry.html#indexDataPattern

        **QSGGeometry::DataPattern QSGGeometry::indexDataPattern() const**

        Returns the usage pattern for indices in this geometry. The default
        pattern is **AlwaysUploadPattern** .

        **See also** **setIndexDataPattern** ().
        """
        ...

    def setIndexDataPattern(self, p: "QSGGeometry.DataPattern") -> None:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#setIndexDataPattern

        **void QSGGeometry::setIndexDataPattern(QSGGeometry::DataPattern p )**

        Sets the usage pattern for indices to **p**.

        The default is **AlwaysUploadPattern** . When set to anything other than
        the default, the user must call **markIndexDataDirty** () after changing
        the index data, in addition to calling **QSGNode::markDirty** () with
        **QSGNode::DirtyGeometry** .

        **See also** **indexDataPattern** ().
        """
        ...

    @staticmethod
    def updateTexturedRectGeometry(
        g: "QSGGeometry", rect: QtCore.QRectF, sourceRect: QtCore.QRectF
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#updateTexturedRectGeometry

        **[static] void QSGGeometry::updateTexturedRectGeometry(QSGGeometry * g
        , const QRectF & rect , const QRectF & textureRect )**

        Updates the geometry **g** with the coordinates in **rect** and texture
        coordinates from **textureRect**.

        **textureRect** should be in normalized coordinates.

        **g** is assumed to be a triangle strip of four vertices of type
        **QSGGeometry::TexturedPoint2D** .
        """
        ...

    @staticmethod
    def updateRectGeometry(g: "QSGGeometry", rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#updateRectGeometry

        **[static] void QSGGeometry::updateRectGeometry(QSGGeometry * g , const
        QRectF & rect )**

        Updates the geometry **g** with the coordinates in **rect**.

        The function assumes the geometry object contains a single triangle
        strip of **QSGGeometry::Point2D**  vertices
        """
        ...

    def sizeOfVertex(self) -> int:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#sizeOfVertex

        **int QSGGeometry::sizeOfVertex() const**

        Returns the size in bytes of one vertex.

        This value comes from the attributes.
        """
        ...

    def attributes(self) -> PyQt6.sip.array[QSGGeometry.Attribute]:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#attributes

        **const QSGGeometry::Attribute *QSGGeometry::attributes() const**

        Returns an array with the attributes of this geometry. The size of the
        array is given with **attributeCount** ().
        """
        ...

    def attributeCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#attributeCount

        **int QSGGeometry::attributeCount() const**

        Returns the number of attributes in the attrbute set used by this
        geometry.
        """
        ...

    def indexData(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#indexData

        **void *QSGGeometry::indexData()**

        Returns a pointer to the raw index data of this geometry object.

        **See also** **indexDataAsUShort** () and **indexDataAsUInt** ().
        """
        ...

    def indexCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#indexCount

        **int QSGGeometry::indexCount() const**

        Returns the number of indices in this geometry object.
        """
        ...

    def indexType(self) -> int:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#indexType

        **int QSGGeometry::indexType() const**

        Returns the primitive type used for indices in this geometry object.
        """
        ...

    def vertexData(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#vertexData

        **void *QSGGeometry::vertexData()**

        Returns a pointer to the raw vertex data of this geometry object.

        **See also** **vertexDataAsPoint2D** () and
        **vertexDataAsTexturedPoint2D** ().
        """
        ...

    def vertexCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#vertexCount

        **int QSGGeometry::vertexCount() const**

        Returns the number of vertices in this geometry object.
        """
        ...

    def allocate(self, vertexCount: int, indexCount: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#allocate

        **void QSGGeometry::allocate(int vertexCount , int indexCount = 0)**

        Resizes the vertex and index data of this geometry object to fit
        **vertexCount** vertices and **indexCount** indices.

        Vertex and index data will be invalidated after this call and the caller
        must mark the associated geometry node as dirty, by calling
        node->markDirty(**QSGNode::DirtyGeometry** ) to ensure that the renderer
        has a chance to update internal buffers.
        """
        ...

    def drawingMode(self) -> int:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#drawingMode

        **unsigned int QSGGeometry::drawingMode() const**

        Returns the drawing mode of this geometry.

        The default value is **DrawTriangleStrip** .

        **See also** **setDrawingMode** ().
        """
        ...

    def setDrawingMode(self, mode: int) -> None:
        """
        https://doc.qt.io/qt-6/qsggeometry.html#setDrawingMode

        **void QSGGeometry::setDrawingMode(unsigned int mode )**

        Sets the **mode** to be used for drawing this geometry.

        The default value is **QSGGeometry::DrawTriangleStrip** .

        **See also** **drawingMode** () and **DrawingMode** .
        """
        ...

    @staticmethod
    def defaultAttributes_ColoredPoint2D() -> "QSGGeometry.AttributeSet":
        """
        https://doc.qt.io/qt-6/qsggeometry.html#defaultAttributes_ColoredPoint2D

        **[static] const QSGGeometry::AttributeSet
        &QSGGeometry::defaultAttributes_ColoredPoint2D()**

        Convenience function which returns attributes to be used for per vertex
        colored 2D drawing.
        """
        ...

    @staticmethod
    def defaultAttributes_TexturedPoint2D() -> "QSGGeometry.AttributeSet":
        """
        https://doc.qt.io/qt-6/qsggeometry.html#defaultAttributes_TexturedPoint2
        D

        **[static] const QSGGeometry::AttributeSet
        &QSGGeometry::defaultAttributes_TexturedPoint2D()**

        Convenience function which returns attributes to be used for textured 2D
        drawing.
        """
        ...

    @staticmethod
    def defaultAttributes_Point2D() -> "QSGGeometry.AttributeSet":
        """
        https://doc.qt.io/qt-6/qsggeometry.html#defaultAttributes_Point2D

        **[static] const QSGGeometry::AttributeSet
        &QSGGeometry::defaultAttributes_Point2D()**

        Convenience function which returns attributes to be used for 2D solid
        color drawing.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QRubberBand(QWidget):
    """
    https://doc.qt.io/qt-6/qrubberband.html

    **Detailed Description**

    A rubber band is often used to show a new bounding area (as in a
    **QSplitter**  or a **QDockWidget**  that is undocking). Historically this
    has been implemented using a **QPainter**  and XOR, but this approach
    doesn't always work properly since rendering can happen in the window below
    the rubber band, but before the rubber band has been "erased".

    You can create a QRubberBand whenever you need to render a rubber band
    around a given area (or to represent a single line), then call
    **setGeometry** (), **move** () or **resize** () to position and size it. A
    common pattern is to do this in conjunction with mouse events. For example:

    void Widget::mousePressEvent(**QMouseEvent**  *event)
        {
            origin =
    event->pos();
            if (!rubberBand)
                rubberBand = new
    **QRubberBand** (**QRubberBand** ::Rectangle, this);
    rubberBand->setGeometry(**QRect** (origin, **QSize** ()));
    rubberBand->show();
        }

        void
    Widget::mouseMoveEvent(**QMouseEvent**  *event)
        {
    rubberBand->setGeometry(**QRect** (origin, event->pos()).normalized());
    }

        void Widget::mouseReleaseEvent(**QMouseEvent**  *event)
        {
    rubberBand->hide();
            // determine selection, for example using
    QRect::intersects()
            // and QRect::contains().
        }

    If you pass a parent to QRubberBand's constructor, the rubber band will
    display only inside its parent, but stays on top of other child widgets. If
    no parent is passed, QRubberBand will act as a top-level widget.

    Call **show** () to make the rubber band visible; also when the rubber band
    is not a top-level. Hiding or destroying the widget will make the rubber
    band disappear. The rubber band can be a **Rectangle**  or a **Line**
    (vertical or horizontal), depending on the **shape** () it was given when
    constructed.
    """

    class Shape(enum.Enum):
        Line: QRubberBand = ...
        Rectangle: QRubberBand = ...

    def __init__(
        self, a0: "QRubberBand.Shape", parent: typing.Optional[QWidget] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#QRubberBand

        **QRubberBand::QRubberBand(QRubberBand::Shape s , QWidget * p =
        nullptr)**

        Constructs a rubber band of shape **s** , with parent **p**.

        By default a rectangular rubber band ( **s** is `Rectangle`) will use a
        mask, so that a small border of the rectangle is all that is visible.
        Some styles (e.g., native macOS) will change this and call
        **QWidget::setWindowOpacity** () to make a semi-transparent filled
        selection rectangle.
        """
        ...

    def moveEvent(self, a0: QtGui.QMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#moveEvent

        **[override virtual protected] void QRubberBand::moveEvent(QMoveEvent
        *)**

        Reimplements: **QWidget::moveEvent** (QMoveEvent *event).
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#resizeEvent

        **[override virtual protected] void
        QRubberBand::resizeEvent(QResizeEvent *)**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).
        """
        ...

    def showEvent(self, a0: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#showEvent

        **[override virtual protected] void QRubberBand::showEvent(QShowEvent *
        e )**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#changeEvent

        **[override virtual protected] void QRubberBand::changeEvent(QEvent * e
        )**

        Reimplements: **QWidget::changeEvent** (QEvent *event).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#paintEvent

        **[override virtual protected] void QRubberBand::paintEvent(QPaintEvent
        *)**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qrubberband.html#event

        **[override virtual protected] bool QRubberBand::event(QEvent * e )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def initStyleOption(self, option: "QStyleOptionRubberBand") -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#initStyleOption

        **[virtual protected] void
        QRubberBand::initStyleOption(QStyleOptionRubberBand * option ) const**

        Initialize **option** with the values from this **QRubberBand** . This
        method is useful for subclasses when they need a
        **QStyleOptionRubberBand** , but don't want to fill in all the
        information themselves.

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    @typing.overload
    def resize(self, w: int, h: int) -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#resize

        **void QRubberBand::resize(int width , int height )**

        Resizes the rubberband so that its width is **width** , and its height
        is **height**.

        **See also** **move** ().
        """
        ...

    @typing.overload
    def resize(self, s: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#resize-1

        **void QRubberBand::resize(const QSize & size )**

        This is an overloaded function.

        Resizes the rubberband so that its new size is **size**.

        **See also** **move** ().
        """
        ...

    @typing.overload
    def move(self, p: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#move

        **void QRubberBand::move(int x , int y )**

        Moves the rubberband to point ( **x** , **y** ).

        **See also** **resize** ().
        """
        ...

    @typing.overload
    def move(self, ax: int, ay: int) -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#move-1

        **void QRubberBand::move(const QPoint & p )**

        This is an overloaded function.

        Moves the rubberband to point **p**.

        **See also** **resize** ().
        """
        ...

    @typing.overload
    def setGeometry(self, r: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#setGeometry

        **void QRubberBand::setGeometry(const QRect & rect )**

        Sets the geometry of the rubber band to **rect** , specified in the
        coordinate system of its parent widget.

        **See also** **QWidget::geometry** .
        """
        ...

    @typing.overload
    def setGeometry(self, ax: int, ay: int, aw: int, ah: int) -> None:
        """
        https://doc.qt.io/qt-6/qrubberband.html#setGeometry-1

        **void QRubberBand::setGeometry(int x , int y , int width , int height
        )**

        This is an overloaded function.

        Sets the geometry of the rubberband to the rectangle whose top-left
        corner lies at the point ( **x** , **y** ), and with dimensions
        specified by **width** and **height**. The geometry is specified in the
        parent widget's coordinate system.
        """
        ...

    def shape(self) -> "QRubberBand.Shape":
        """
        https://doc.qt.io/qt-6/qrubberband.html#shape

        **QRubberBand::Shape QRubberBand::shape() const**

        Returns the shape of this rubber band. The shape can only be set upon
        construction.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QStatusBar(QWidget):
    """
    https://doc.qt.io/qt-6/qstatusbar.html

    **Detailed Description**

    Each status indicator falls into one of three categories:

    * **Temporary** \\- briefly occupies most of the status bar. Used to explain
    tool tip texts or menu entries, for example.
      * **Normal** \\- occupies part
    of the status bar and may be hidden by temporary messages. Used to display
    the page and line number in a word processor, for example.
      * **Permanent**
    \\- is never hidden. Used for important mode indications, for example, some
    applications put a Caps Lock indicator in the status bar.

    QStatusBar lets you display all three types of indicators.

    Typically, a request for the status bar functionality occurs in relation to
    a **QMainWindow**  object. **QMainWindow**  provides a main application
    window, with a menu bar, tool bars, dock widgets **and** a status bar around
    a large central widget. The status bar can be retrieved using the
    **QMainWindow::statusBar** () function, and replaced using the
    **QMainWindow::setStatusBar** () function.

    Use the **showMessage** () slot to display a **temporary** message:

    void MainWindow::createStatusBar()
        {
    statusBar()->showMessage(tr("Ready"));
        }

    To remove a temporary message, use the **clearMessage** () slot, or set a
    time limit when calling **showMessage** (). For example:

    void MainWindow::print()
        {
        #if defined(QT_PRINTSUPPORT_LIB) &&
    QT_CONFIG(printdialog)
            **QTextDocument**  *document =
    textEdit->document();
            QPrinter printer;

            QPrintDialog
    dlg(&printer, this);
            if (dlg.exec() != **QDialog** ::Accepted) {
    return;
            }

            document->print(&printer);
    statusBar()->showMessage(tr("Ready"), 2000);
        #endif
        }

    Use the **currentMessage** () function to retrieve the temporary message
    currently shown. The QStatusBar class also provide the **messageChanged** ()
    signal which is emitted whenever the temporary status message changes.

    **Normal** and **Permanent** messages are displayed by creating a small
    widget (**QLabel** , **QProgressBar**  or even **QToolButton** ) and then
    adding it to the status bar using the **addWidget** () or the
    **addPermanentWidget** () function. Use the **removeWidget** () function to
    remove such messages from the status bar.

    statusBar()->addWidget(new MyReadWriteIndication);

    By default QStatusBar provides a **QSizeGrip**  in the lower-right corner.
    You can disable it using the **setSizeGripEnabled** () function. Use the
    **isSizeGripEnabled** () function to determine the current status of the
    size grip.

    ![A status bar shown in the Fusion widget style](images/fusion-statusbar-
    sizegrip.png)

    **See also** **QMainWindow** , **QStatusTipEvent** , **GUI Design Handbook:
    Status Bar** , and **Qt Widgets - Application Example** .
    """

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#QStatusBar

        **QStatusBar::QStatusBar(QWidget * parent = nullptr)**

        Constructs a status bar with a size grip and the given **parent**.

        **See also** **setSizeGripEnabled** ().
        """
        ...

    def showEvent(self, a0: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#showEvent

        **[override virtual protected] void QStatusBar::showEvent(QShowEvent
        *)**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#event

        **[override virtual protected] bool QStatusBar::event(QEvent * e )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def hideOrShow(self) -> None:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#hideOrShow

        **[protected] void QStatusBar::hideOrShow()**

        Ensures that the right widgets are visible.

        Used by the **showMessage** () and **clearMessage** () functions.
        """
        ...

    def reformat(self) -> None:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#reformat

        **[protected] void QStatusBar::reformat()**

        Changes the status bar's appearance to account for item changes.

        Special subclasses may need this function, but geometry management will
        usually take care of any necessary rearrangements.
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#resizeEvent

        **[override virtual protected] void QStatusBar::resizeEvent(QResizeEvent
        * e )**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#paintEvent

        **[override virtual protected] void QStatusBar::paintEvent(QPaintEvent *
        event )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).

        Shows the temporary message, if appropriate, in response to the paint
        **event**.
        """
        ...

    def clearMessage(self) -> None:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#clearMessage

        **[slot] void QStatusBar::clearMessage()**

        Removes any temporary message being shown.

        **See also** **currentMessage** (), **showMessage** (), and
        **removeWidget** ().
        """
        ...

    def showMessage(self, message: str, msecs: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#showMessage

        **[slot] void QStatusBar::showMessage(const QString & message , int
        timeout = 0)**

        Hides the normal status indications and displays the given **message**
        for the specified number of milli-seconds ( **timeout** ). If
        **timeout** is 0 (default), the **message** remains displayed until the
        **clearMessage** () slot is called or until the showMessage() slot is
        called again to change the message.

        Note that showMessage() is called to show temporary explanations of tool
        tip texts, so passing a **timeout** of 0 is not sufficient to display a
        **permanent message** .

        **See also** **messageChanged** (), **currentMessage** (), and
        **clearMessage** ().
        """
        ...

    def insertPermanentWidget(
        self, index: int, widget: QWidget, stretch: int = ...
    ) -> int:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#insertPermanentWidget

        **int QStatusBar::insertPermanentWidget(int index , QWidget * widget ,
        int stretch = 0)**

        Inserts the given **widget** at the given **index** permanently to this
        status bar, reparenting the widget if it isn't already a child of this
        **QStatusBar**  object. If **index** is out of range, the widget is
        appended (in which case it is the actual index of the widget that is
        returned).

        The **stretch** parameter is used to compute a suitable size for the
        given **widget** as the status bar grows and shrinks. The default
        stretch factor is 0, i.e giving the widget a minimum of space.

        Permanently means that the widget may not be obscured by temporary
        messages. It is is located at the far right of the status bar.

        **See also** **addPermanentWidget** (), **removeWidget** (), and
        **addWidget** ().
        """
        ...

    def insertWidget(self, index: int, widget: QWidget, stretch: int = ...) -> int:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#insertWidget

        **int QStatusBar::insertWidget(int index , QWidget * widget , int
        stretch = 0)**

        Inserts the given **widget** at the given **index** to this status bar,
        reparenting the widget if it isn't already a child of this
        **QStatusBar**  object. If **index** is out of range, the widget is
        appended (in which case it is the actual index of the widget that is
        returned).

        The **stretch** parameter is used to compute a suitable size for the
        given **widget** as the status bar grows and shrinks. The default
        stretch factor is 0, i.e giving the widget a minimum of space.

        The widget is located to the far left of the first permanent widget (see
        **addPermanentWidget** ()) and may be obscured by temporary messages.

        **See also** **addWidget** (), **removeWidget** (), and
        **addPermanentWidget** ().
        """
        ...

    def currentMessage(self) -> str:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#currentMessage

        **QString QStatusBar::currentMessage() const**

        Returns the temporary message currently shown, or an empty string if
        there is no such message.

        **See also** **showMessage** ().
        """
        ...

    def isSizeGripEnabled(self) -> bool:
        ...

    def setSizeGripEnabled(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#sizeGripEnabled-prop

        **sizeGripEnabled : bool**

        This property holds whether the **QSizeGrip**  in the bottom-right
        corner of the status bar is enabled

        The size grip is enabled by default.

        **Access functions:**

        bool **isSizeGripEnabled** () const
        void **setSizeGripEnabled** (bool)

        **Member Function Documentation**
        """
        ...

    def removeWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#removeWidget

        **void QStatusBar::removeWidget(QWidget * widget )**

        Removes the specified **widget** from the status bar.

        **Note:** This function does not delete the widget but **hides** it. To
        add the widget again, you must call both the **addWidget** () and
        **show** () functions.

        **See also** **addWidget** (), **addPermanentWidget** (), and
        **clearMessage** ().
        """
        ...

    def addPermanentWidget(self, widget: QWidget, stretch: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#addPermanentWidget

        **void QStatusBar::addPermanentWidget(QWidget * widget , int stretch =
        0)**

        Adds the given **widget** permanently to this status bar, reparenting
        the widget if it isn't already a child of this **QStatusBar**  object.
        The **stretch** parameter is used to compute a suitable size for the
        given **widget** as the status bar grows and shrinks. The default
        stretch factor is 0, i.e giving the widget a minimum of space.

        Permanently means that the widget may not be obscured by temporary
        messages. It is is located at the far right of the status bar.

        **See also** **insertPermanentWidget** (), **removeWidget** (), and
        **addWidget** ().
        """
        ...

    def addWidget(self, widget: QWidget, stretch: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#addWidget

        **void QStatusBar::addWidget(QWidget * widget , int stretch = 0)**

        Adds the given **widget** to this status bar, reparenting the widget if
        it isn't already a child of this **QStatusBar**  object. The **stretch**
        parameter is used to compute a suitable size for the given **widget** as
        the status bar grows and shrinks. The default stretch factor is 0, i.e
        giving the widget a minimum of space.

        The widget is located to the far left of the first permanent widget (see
        **addPermanentWidget** ()) and may be obscured by temporary messages.

        **See also** **insertWidget** (), **removeWidget** (), and
        **addPermanentWidget** ().
        """
        ...

    @property
    def messageChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qstatusbar.html#messageChanged

        **[signal] void QStatusBar::messageChanged(const QString & message )**

        This signal is emitted whenever the temporary status message changes.
        The new temporary message is passed in the **message** parameter which
        is a null-string when the message has been removed.

        **See also** **showMessage** () and **clearMessage** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QVector3D(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qvector3d.html

    **Detailed Description**

    Vectors are one of the main building blocks of 3D representation and
    drawing. They consist of three finite floating-point coordinates,
    traditionally called x, y, and z.

    The QVector3D class can also be used to represent vertices in 3D space. We
    therefore do not need to provide a separate vertex class.

    **See also** **QVector2D** , **QVector4D** , and **QQuaternion** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qvector3d.html#QVector3D

        **QVector3D::QVector3D()**

        Constructs a null vector, i.e. with coordinates (0, 0, 0).
        """
        ...

    @typing.overload
    def __init__(self, xpos: float, ypos: float, zpos: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector3d.html#QVector3D-2

        **QVector3D::QVector3D(float xpos , float ypos , float zpos )**

        Constructs a vector with coordinates ( **xpos** , **ypos** , **zpos** ).
        All parameters must be finite.
        """
        ...

    @typing.overload
    def __init__(self, point: QtCore.QPoint) -> None:
        """
        https://doc.qt.io/qt-6/qvector3d.html#QVector3D-3

        **QVector3D::QVector3D(QPoint point )**

        Constructs a vector with x and y coordinates from a 2D **point** , and a
        z coordinate of 0.
        """
        ...

    @typing.overload
    def __init__(self, point: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qvector3d.html#QVector3D-4

        **QVector3D::QVector3D(QPointF point )**

        Constructs a vector with x and y coordinates from a 2D **point** , and a
        z coordinate of 0.
        """
        ...

    @typing.overload
    def __init__(self, vector: QVector2D, zpos: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector3d.html#QVector3D-5

        **QVector3D::QVector3D(QVector2D vector )**

        Constructs a 3D vector from the specified 2D **vector**. The z
        coordinate is set to zero.

        **See also** **toVector2D** ().
        """
        ...

    @typing.overload
    def __init__(self, vector: QVector2D) -> None:
        """
        https://doc.qt.io/qt-6/qvector3d.html#QVector3D-6

        **QVector3D::QVector3D(QVector2D vector , float zpos )**

        Constructs a 3D vector from the specified 2D **vector**. The z
        coordinate is set to **zpos** , which must be finite.

        **See also** **toVector2D** ().
        """
        ...

    @typing.overload
    def __init__(self, vector: "QVector4D") -> None:
        """
        https://doc.qt.io/qt-6/qvector3d.html#QVector3D-7

        **QVector3D::QVector3D(QVector4D vector )**

        Constructs a 3D vector from the specified 4D **vector**. The w
        coordinate is dropped.

        **See also** **toVector4D** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QVector3D") -> None:
        """
        https://doc.qt.io/qt-6/qvector3d.html#QVector3D

        **QVector3D::QVector3D()**

        Constructs a null vector, i.e. with coordinates (0, 0, 0).
        """
        ...

    def __neg__(self) -> "QVector3D":
        ...

    def toPointF(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qvector3d.html#toPointF

        **QPointF QVector3D::toPointF() const**

        Returns the **QPointF**  form of this 3D vector. The z coordinate is
        dropped.

        **See also** **toPoint** () and **toVector2D** ().
        """
        ...

    def toPoint(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qvector3d.html#toPoint

        **QPoint QVector3D::toPoint() const**

        Returns the **QPoint**  form of this 3D vector. The z coordinate is
        dropped. The x and y coordinates are rounded to nearest integers.

        **See also** **toPointF** () and **toVector2D** ().
        """
        ...

    def toVector4D(self) -> "QVector4D":
        """
        https://doc.qt.io/qt-6/qvector3d.html#toVector4D

        **QVector4D QVector3D::toVector4D() const**

        Returns the 4D form of this 3D vector, with the w coordinate set to
        zero.

        **See also** **toVector2D** () and **toPoint** ().
        """
        ...

    def toVector2D(self) -> QVector2D:
        """
        https://doc.qt.io/qt-6/qvector3d.html#toVector2D

        **QVector2D QVector3D::toVector2D() const**

        Returns the 2D vector form of this 3D vector, dropping the z coordinate.

        **See also** **toVector4D** () and **toPoint** ().
        """
        ...

    def distanceToLine(self, point: "QVector3D", direction: "QVector3D") -> float:
        """
        https://doc.qt.io/qt-6/qvector3d.html#distanceToLine

        **float QVector3D::distanceToLine(QVector3D point , QVector3D direction
        ) const**

        Returns the distance that this vertex is from a line defined by
        **point** and the unit vector **direction**.

        If **direction** is a null vector, then it does not define a line. In
        that case, the distance from **point** to this vertex is returned.

        **See also** **distanceToPlane** ().
        """
        ...

    @typing.overload
    def distanceToPlane(self, plane: "QVector3D", normal: "QVector3D") -> float:
        """
        https://doc.qt.io/qt-6/qvector3d.html#distanceToPlane

        **float QVector3D::distanceToPlane(QVector3D plane , QVector3D normal )
        const**

        Returns the distance from this vertex to a plane defined by the vertex
        **plane** and a **normal** unit vector. The **normal** parameter is
        assumed to have been normalized to a unit vector.

        The return value will be negative if the vertex is below the plane, or
        zero if it is on the plane.

        **See also** **normal** () and **distanceToLine** ().
        """
        ...

    @typing.overload
    def distanceToPlane(
        self, plane1: "QVector3D", plane2: "QVector3D", plane3: "QVector3D"
    ) -> float:
        """
        https://doc.qt.io/qt-6/qvector3d.html#distanceToPlane-1

        **float QVector3D::distanceToPlane(QVector3D plane1 , QVector3D plane2 ,
        QVector3D plane3 ) const**

        Returns the distance from this vertex to a plane defined by the vertices
        **plane1** , **plane2** and **plane3**.

        The return value will be negative if the vertex is below the plane, or
        zero if it is on the plane.

        The two vectors that define the plane are **plane2** \\- **plane1** and
        **plane3** \\- **plane1**.

        **See also** **normal** () and **distanceToLine** ().
        """
        ...

    def distanceToPoint(self, point: "QVector3D") -> float:
        """
        https://doc.qt.io/qt-6/qvector3d.html#distanceToPoint

        **[since 5.1] float QVector3D::distanceToPoint(QVector3D point ) const**

        Returns the distance from this vertex to a point defined by the vertex
        **point**.

        This function was introduced in Qt 5.1.

        **See also** **distanceToPlane** () and **distanceToLine** ().
        """
        ...

    def unproject(
        self, modelView: QMatrix4x4, projection: QMatrix4x4, viewport: QtCore.QRect
    ) -> "QVector3D":
        """
        https://doc.qt.io/qt-6/qvector3d.html#unproject

        **[since 5.5] QVector3D QVector3D::unproject(const QMatrix4x4 &
        modelView , const QMatrix4x4 & projection , const QRect & viewport )
        const**

        Returns the object/model coordinates of this vector initially in window
        coordinates using the model view matrix **modelView** , the projection
        matrix **projection** and the viewport dimensions **viewport**.

        When transforming from clip to normalized space, a division by the w
        component of the vector components takes place. To prevent dividing by 0
        if w equals to 0, it is set to 1.

        **Note:** y coordinates in **viewport** should use OpenGL orientation.
        OpenGL expects the bottom to be 0 whereas for Qt top is 0.

        This function was introduced in Qt 5.5.

        **See also** **project** ().
        """
        ...

    def project(
        self, modelView: QMatrix4x4, projection: QMatrix4x4, viewport: QtCore.QRect
    ) -> "QVector3D":
        """
        https://doc.qt.io/qt-6/qvector3d.html#project

        **[since 5.5] QVector3D QVector3D::project(const QMatrix4x4 & modelView
        , const QMatrix4x4 & projection , const QRect & viewport ) const**

        Returns the window coordinates of this vector initially in object/model
        coordinates using the model view matrix **modelView** , the projection
        matrix **projection** and the viewport dimensions **viewport**.

        When transforming from clip to normalized space, a division by the w
        component on the vector components takes place. To prevent dividing by 0
        if w equals to 0, it is set to 1.

        **Note:** the returned y coordinates are in OpenGL orientation. OpenGL
        expects the bottom to be 0 whereas for Qt top is 0.

        This function was introduced in Qt 5.5.

        **See also** **unproject** ().
        """
        ...

    @typing.overload
    @staticmethod
    def normal(v1: "QVector3D", v2: "QVector3D") -> "QVector3D":
        """
        https://doc.qt.io/qt-6/qvector3d.html#normal

        **[static] QVector3D QVector3D::normal(QVector3D v1 , QVector3D v2 )**

        Returns the unit normal vector of a plane spanned by vectors **v1** and
        **v2** , which must not be parallel to one another.

        Use **crossProduct** () to compute the cross-product of **v1** and
        **v2** if you do not need the result to be normalized to a unit vector.

        **See also** **crossProduct** () and **distanceToPlane** ().
        """
        ...

    @typing.overload
    @staticmethod
    def normal(v1: "QVector3D", v2: "QVector3D", v3: "QVector3D") -> "QVector3D":
        """
        https://doc.qt.io/qt-6/qvector3d.html#normal-1

        **[static] QVector3D QVector3D::normal(QVector3D v1 , QVector3D v2 ,
        QVector3D v3 )**

        Returns the unit normal vector of a plane spanned by vectors **v2** \\-
        **v1** and **v3** \\- **v1** , which must not be parallel to one another.

        Use **crossProduct** () to compute the cross-product of **v2** \\- **v1**
        and **v3** \\- **v1** if you do not need the result to be normalized to a
        unit vector.

        **See also** **crossProduct** () and **distanceToPlane** ().
        """
        ...

    @staticmethod
    def crossProduct(v1: "QVector3D", v2: "QVector3D") -> "QVector3D":
        """
        https://doc.qt.io/qt-6/qvector3d.html#crossProduct

        **[static] QVector3D QVector3D::crossProduct(QVector3D v1 , QVector3D v2
        )**

        Returns the cross-product of vectors **v1** and **v2** , which is normal
        to the plane spanned by **v1** and **v2**. It will be zero if the two
        vectors are parallel.

        **See also** **normal** ().
        """
        ...

    @staticmethod
    def dotProduct(v1: "QVector3D", v2: "QVector3D") -> float:
        """
        https://doc.qt.io/qt-6/qvector3d.html#dotProduct

        **[static] float QVector3D::dotProduct(QVector3D v1 , QVector3D v2 )**

        Returns the dot product of **v1** and **v2**.
        """
        ...

    def normalize(self) -> None:
        """
        https://doc.qt.io/qt-6/qvector3d.html#normalize

        **void QVector3D::normalize()**

        Normalizes the currect vector in place. Nothing happens if this vector
        is a null vector or the length of the vector is very close to 1.

        **See also** **length** () and **normalized** ().
        """
        ...

    def normalized(self) -> "QVector3D":
        """
        https://doc.qt.io/qt-6/qvector3d.html#normalized

        **QVector3D QVector3D::normalized() const**

        Returns the normalized unit vector form of this vector.

        If this vector is null, then a null vector is returned. If the length of
        the vector is very close to 1, then the vector will be returned as-is.
        Otherwise the normalized form of the vector of length 1 will be
        returned.

        **See also** **length** () and **normalize** ().
        """
        ...

    def lengthSquared(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector3d.html#lengthSquared

        **float QVector3D::lengthSquared() const**

        Returns the squared length of the vector from the origin. This is
        equivalent to the dot product of the vector with itself.

        **See also** **length** () and **dotProduct** ().
        """
        ...

    def length(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector3d.html#length

        **float QVector3D::length() const**

        Returns the length of the vector from the origin.

        **See also** **lengthSquared** () and **normalized** ().
        """
        ...

    def __getitem__(self, i: int) -> float:
        ...

    def setZ(self, z: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector3d.html#setZ

        **void QVector3D::setZ(float z )**

        Sets the z coordinate of this point to the given finite **z**
        coordinate.

        **See also** **z** (), **setX** (), and **setY** ().
        """
        ...

    def setY(self, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector3d.html#setY

        **void QVector3D::setY(float y )**

        Sets the y coordinate of this point to the given finite **y**
        coordinate.

        **See also** **y** (), **setX** (), and **setZ** ().
        """
        ...

    def setX(self, x: float) -> None:
        """
        https://doc.qt.io/qt-6/qvector3d.html#setX

        **void QVector3D::setX(float x )**

        Sets the x coordinate of this point to the given finite **x**
        coordinate.

        **See also** **x** (), **setY** (), and **setZ** ().
        """
        ...

    def z(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector3d.html#z

        **float QVector3D::z() const**

        Returns the z coordinate of this point.

        **See also** **setZ** (), **x** (), and **y** ().
        """
        ...

    def y(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector3d.html#y

        **float QVector3D::y() const**

        Returns the y coordinate of this point.

        **See also** **setY** (), **x** (), and **z** ().
        """
        ...

    def x(self) -> float:
        """
        https://doc.qt.io/qt-6/qvector3d.html#x

        **float QVector3D::x() const**

        Returns the x coordinate of this point.

        **See also** **setX** (), **y** (), and **z** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qvector3d.html#isNull

        **bool QVector3D::isNull() const**

        Returns `true` if the x, y, and z coordinates are set to 0.0, otherwise
        returns `false`.
        """
        ...

    def __repr__(self) -> str:
        ...
